#! /usr/bin/env python 
# -*- coding: utf-8 -*-
###################################################################################
# Program   : DragSB
# Author    : Vincent Descotes, 7/07/2010 
# Purpose   : create a file in 'pwd' where all mixtures are numbered 
#             for the single block problem.
# ATTENTION : you need to provide manually the good number of cells in GEO:
#             (by modifying this script, line 174). At least, verify it.
# Input     : Nbg : int : number of groups for the condensation
# Output    : file fuel_cell_XXXgr_f.x2m in current directory. Ready to run.
###################################################################################
def DragSB(Nbg):
  import os
  import numpy

  # Number of groups for the condensation :
  gr=[Nbg]

  #Opening file supercell_XXXgr_33r.x2m for writing
  INPTPATH = os.getcwd()
  f = open(INPTPATH+'/Mike_block_'+str(gr[0])+'gr_f.x2m', 'w')

  # Header in DRAGON
  f.write("*--------------------------------------------------------------------\n")
  f.write("* DB-VHTR Fuel Block Lattice calculation\n")
  f.write("* Fresh fuel TRU loading\n")
  f.write("* Author : V. Descotes\n")
  f.write("* Core corner block(6,1), no BP, no CR.\n")
  f.write("* JEFF3.1.0\n")  
  f.write("* SHEM295 Group Structure\n\n") 
  f.write("*--------------------------------------------------------------------\n")
  f.write("* Define variables \n")
  f.write("*    Burnup parameters :\n")
  f.write("*    a) Power = 600.0 MW.tonne^-1 = 600.0 kW.kg^-1 \n")
  f.write("*    b) Burnup time intervals Delt :\n")
  f.write("*        = 10 days for 0 to 50 days\n")
  f.write("*        = 50 days for 50 to 500 days\n")
  f.write("*        = 100 days for 500 to 1000 days\n")
  f.write("*    c) Editing time Timec\n")
  f.write("*        = 0.0 50.0 500.0 and 1000.0 days\n")
  f.write("*    d) Burnup control time variables\n")
  f.write("*        Timei = initial time \n")
  f.write("*        Timef = final time \n")
  f.write("*        TotalTime = Final time reached \n")
  f.write("*    e) Print variable Iprint \n")
  f.write("*         = 1 reduced print\n")
  f.write("*         = 3 full print \n")
  f.write("*    f) Count the number of output files : I (integer) \n")
  f.write("*--------------------------------------------------------------------\n*\n")
  f.write("*--------------------------------------------------------------------\n")  
  f.write("*  Define variables used\n")
  f.write("*-------------------------------------------------------------------- \n")
  f.write("REAL\n")
  f.write("  Power Delt Timec Timei Timef TotalTime :=\n")
  f.write("  600.0 10.0 50.0   0.0    0.0  1000.0 ;\n")
  f.write("INTEGER\n")
  f.write("  Iprint I  := 1 1 ;\n")
  f.write("*--------------------------------------------------------------------\n")  
  f.write("*  Define STRUCTURES and MODULES used\n")
  f.write("*-------------------------------------------------------------------- \n")
  # Structures and modules in DRAGON

  f.write('LINKED_LIST \n')
  f.write('   LIBRARY LIBRARY2 GEOM SYS FLUX CPO\n')
  f.write("   OUTFUEL ;\n\n")

  f.write("XSM_FILE TRACK1 BURNUP ;\n\n")
#  f.write("SEQ_BINARY TRACK_FIL1 ;\n\n")

  f.write("SEQ_ASCII Outfuel0 Outfuel1 Outfuel2 Outfuel3 OutI OutF ;\n")

  f.write("MODULE\n")
  f.write("  GEO: LIB: ASM: FLU: EDI: DELETE: END:\n")
  f.write("  COMPO: USS: EXCELT: SYBILT: MCCGT: EVO: ;\n\n")


  # Association of a mixture number to each element of each block
  f.write("*--------------------------------------------------------------------\n")
  f.write("* CREATION OF THE LIBRARY \n")
  f.write("*--------------------------------------------------------------------\n\n")
    
  f.write('LIBRARY := LIB: ::\n')
  f.write('  EDIT 0\n')
  f.write('  NMIX 86 CTRA APOL ANIS 2\n') # The transport correction may be removed if you do anisotropy.
  f.write('  DEPL LIB: DRAGON FIL: JF310SH295\n')
  f.write('  CALENDF 3 PT\n')
  f.write('  MIXS LIB: DRAGON FIL: JF310SH295\n')

# Fuel cells F1, F2... : loop
  i=0
  j=1
  while i!=10:
      f.write("\n*----\n")
      f.write("* Mixtures for fuel cell F"+str(i)+"\n")
      f.write("*----\n")
      f.write('* Graphite matrix\n')
      f.write('  MIX  '+str(j)+' 293.6\n')
      f.write("    GRAB      = 'C0_GR'  8.524E-02\n")
      f.write("* Fuel Kernel\n")
      f.write("  MIX  "+str(j+1)+" 293.6\n")
      f.write("    O16       = 'O16'     4.436E-02\n")
      f.write("    NP27      = 'Np237'   1.522E-03 CORR 1 IRSET PT 1\n")
      f.write("    PU38      = 'Pu238'   6.464E-04 CORR 1 IRSET PT 1\n")
      f.write("    PU39      = 'Pu239'   1.099E-02 CORR 1 IRSET PT 1\n")
      f.write("    PU40      = 'Pu240'   5.084E-03 CORR 1 IRSET PT 1\n")
      f.write("    PU41      = 'Pu241'   1.937E-03 CORR 1 IRSET PT 1\n")
      f.write("    PU42      = 'Pu242'   1.074E-03 CORR 1 IRSET PT 1\n")
      f.write("    AM41      = 'Am241'   6.163E-04 CORR 1 IRSET PT 1\n")
      f.write("    AM42      = 'Am242m'  4.385E-06 CORR 1 IRSET PT 1\n")
      f.write("    AM43      = 'Am243'   3.057E-04 CORR 1 IRSET PT 1\n")
      f.write("* Porous C buffer\n")
      f.write("  MIX  "+str(j+2)+" 293.6\n")
      f.write("    GRAB      = 'C0_GR'   5.265E-02\n")
      f.write("* IPyC\n")
      f.write("  MIX  "+str(j+3)+" 293.6\n")
      f.write("    GRAB      = 'C0_GR'   9.526E-02\n")
      f.write("* SiC coating layer\n")
      f.write("  MIX  "+str(j+4)+" 293.6\n")
      f.write("     SI28     = 'Si28'    4.402E-02\n")
      f.write("     SI29     = 'Si29'    2.235E-03\n")
      f.write("     SI30     = 'Si30'    1.473E-03\n")
      f.write("     C12      = 'C0'      4.772E-02\n")
      f.write("* OPyC\n")
      f.write("  MIX  "+str(j+5)+" 293.6\n")
      f.write("    GRAB      = 'C0_GR' 9.526E-02\n")
      f.write("* Helium Coolant surrounding fuel\n")
      f.write("  MIX "+str(j+6)+" 293.6\n")
      f.write("    HE4      = 'He4'     7.0000E-04\n")
      f.write("* Block Graphite (full density surrounding fuel)\n")
      f.write("  MIX "+str(j+7)+" 293.6\n")
      f.write("    GRAB     = 'C0_GR' 8.774E-02\n")
      j=j+8
      i=i+1

# Other cell (not distinguished)
  f.write("\n*---\n")
  f.write("* Mixtures for other cells\n")
  f.write("*---\n")
  f.write("* Block Graphite (full density not surrounding fuel)\n")
  f.write("  MIX "+str(j)+"  293.6\n")
  f.write("    GRAB     = 'C0_GR' 8.774E-02\n")
  f.write("* Block Graphite (lower density for the J boundary cells)\n")
  f.write("  MIX "+str(j+1)+"  293.6\n")
  f.write("    GRAB      = 'C0_GR' 4.7433769E-02\n")
  f.write("* Block Graphite (full density surrounding large coolant hole)\n")
  f.write("  MIX "+str(j+2)+" 293.6\n")
  f.write("    GRAB     = 'C0_GR' 8.774E-02\n")
  f.write("* Block Graphite (full density surrounding small coolant hole)\n")
  f.write("  MIX "+str(j+3)+" 293.6\n")
  f.write("    GRAB     = 'C0_GR' 8.774E-02\n")
  f.write("* Helium Coolant in small coolant hole\n")
  f.write("  MIX "+str(j+4)+" 293.6\n")
  f.write("    HE4      = 'He4'     7.0000E-04\n")
  f.write("* Helium Coolant in large coolant hole\n") 
  f.write("  MIX "+str(j+5)+" 293.6\n")
  f.write("    HE4      = 'He4'     7.0000E-04\n")

  f.write(";\n")
  Ntot=j+5
  print("Total number of mix = "+str(Ntot))
  f.write("*Total number of mix = "+str(Ntot)+"\n")

  f.write("\n")
  #
  # Write the GEO part
  #

  f.write("*--------------------------------------------------------\n")
  f.write("*  GEOMETRY\n")
  f.write("*--------------------------------------------------------\n")
  f.write("* ----\n")
  f.write("* F = Fuel cell\n")
  f.write("* C = coolant hole cell (large)\n")
  f.write("* K = coolant hole cell (small)\n")
  f.write("* G = Full density graphite cell\n")
  f.write("* J = Reduced density graphite cell\n")
  f.write("* ----\n\n")

  f.write("GEOM := GEO: :: HEX 42\n")
  f.write("  EDIT 0\n")
  f.write("  HBC S30 REFL\n")
  f.write("  CELL\n")
  f.write("* Ring 0\n")
  f.write("G\n")
  f.write("* Ring 1\n")
  f.write("G\n")
  f.write("* Ring 2\n")
  f.write("K F1\n")
  f.write("* Ring 3\n")
  f.write("F2 C\n")
  f.write("* Ring 4\n")
  f.write("C F3 F0\n")
  f.write("* Ring 5\n")
  f.write("F4 C F0\n")
  f.write("* Ring 6\n")
  f.write("C F5 F0 C\n")
  f.write("* Ring 7\n")
  f.write("F6 C F0 F0\n")
  f.write("* Ring 8\n")
  f.write("C F7 F0 C F0\n")
  f.write("* Ring 9\n")
  f.write("F8 C F0 F0 C\n")
  f.write("* Ring 10\n")
  f.write("C F9 F0 C F0 G\n")
  f.write("* Ring 11\n")
  f.write("J J J J J J\n")
  f.write("\n")
  f.write("*---------------------------------------------------------\n")
  f.write("* SPHERICAL MICRO-STRUCTURES *\n")
  f.write("* NMISTR = NUMBER OF MICRO STRUCTURE TYPES IN REGION\n")
  f.write("* NMILG  = NUMBER OF MICRO STRUCTURE REGIONS\n")
  f.write("* NS     = ARRAY OF SUB REGIONS IN THE MICRO STRUCTURES; LEN=NMILG\n")
  f.write("* RS     = RADIUS OF MICROS STRUCTURES; LEN=NS(I); I=1,NMISTR\n")
  f.write("* milie  = COMPOSITION OF EACH shell OF MICRO STRUCTURE; LEN=NMISTR;\n")
  f.write("*          !!!!!!!! milie #'s ARE > THAN MIX #'S !!!!!!!!\n")
  f.write("* mixdil = BASE COMPOSITION OF EACH REGION; LEN=NMILG\n")
  f.write("* fract  = MICROSTRUCTURE TYPE VOLUME FRACTION IN REGION LEN=NMILG\n")
  f.write("* mixgr  = LIBRARY MIXTURES FOR EACH MICROSTRUCTURE SHELL; LEN=NS(I)\n")
  f.write("\n\n")

  f.write("* NMISTR, NMILG\n")
  f.write("  BIHET SPHE  1  10\n")
  f.write("  (* NS     *) 5\n")
  f.write("  (* RS     *) 0.0 0.0100 0.0220 0.0260 0.0295 0.0335\n")
# Loop to get all the fuel cells with different mixtures.
  f.write("  (* milie  *)  ")
  i=0
  j=1
  while i !=10:
      f.write(str(Ntot+i+1)+" ")
      i=i+1
  f.write("\n")
  f.write("  (* mixdil *)  ")
  i=0
  j=1
  while i !=10:
      f.write(str(j)+"  ")
      j=j+8
      i=i+1
  f.write("\n")
  f.write("  (* loop over NMISTR *)\n")
  i=0
  j=1
  while i !=10:
      f.write("  (* fract  *)  0.175016\n")
      f.write("  (* mixgr  *)  "+str(j+1)+" "+str(j+2)+" "+str(j+3)+" "+str(j+4)+" "+str(j+5)+" \n")
      i=i+1
      j=j+8
  #
  # Write the subgeometries
  #
  f.write("*--------------------------------------------------------------------\n")
  f.write("* Cell Definitions\n")
  f.write("*--------------------------------------------------------------------\n")
  f.write("*\n")
  i=0
  j=1
  while i!=10:
      f.write("*  Fuel Cell          (block of interest) --------------------------- \n")
      f.write(" ::: F"+str(i)+" := GEO: HEXCEL 2\n")
      f.write("     SIDE 1.08542 \n")
      f.write("     RADIUS 0.0 0.6225 0.6350\n")
      f.write("     SECT -1 \n")
      f.write("     MIX "+(" "+str(Ntot+i+1)+" ")*6+"\n")
      f.write("         "+(" "+str(j+6)+" ")*6+"\n")
      f.write("         "+(" "+str(j+7)+" ")*6+";\n")
      i=i+1
      j=j+8

  f.write("*  Small coolant Hole (block of interest) ------------------  \n")
  f.write(" ::: K := GEO: HEXCEL 1\n")
  f.write("     SIDE 1.08542 \n")
  f.write("     RADIUS 0.0 0.6350\n")
  f.write("     MIX "+str(j+4)+"\n")
  f.write("         "+str(j+3)+" ;\n")

  f.write("*  Large Coolant Hole (block of interest) ------------------\n")
  f.write(" ::: C := GEO: HEXCEL 1\n")
  f.write("     SIDE 1.08542 \n")
  f.write("     RADIUS 0.0 0.794\n")
  f.write("     MIX "+str(j+5)+"\n")
  f.write("         "+str(j+2)+" ;\n")

  f.write("*  Lower Boundary Density Graphite (for testing only) ------------------\n")
  f.write(" ::: J := GEO: HEX 1\n")
  f.write("     SIDE 1.08542 \n")
  f.write("     MIX "+str(j+1)+" ;\n")

  f.write("*  Full Density Graphite (block of interest) ------------------\n")
  f.write(" ::: G := GEO: HEX 1\n")
  f.write("     SIDE 1.08542 \n")
  f.write("     MIX "+str(j)+" ;\n")
  f.write("*\n")
  f.write(";\n\n\n")

  #
  # Write the tracking, self-shielding and flux calculation parts
  #

  f.write("*--------------------------------------------------------------------\n")
  f.write("*  Use SYBILT, USS, ASM and FLU for flux solution\n")
  f.write("*--------------------------------------------------------------------\n\n")
  f.write("***\n")
  f.write("* Tracking SYBILT\n") 
  f.write("***\n")
  f.write("TRACK1 := SYBILT: GEOM ::\n")
  f.write("    EDIT 0\n")
  f.write("    MAXR 40000\n")
  f.write("    MAXZ 500000\n")
  f.write("    QUA2 4 8\n")
  f.write("    QUAB 5 HEBE\n")
  f.write("    DP01\n")
  f.write("    ;\n")      

  f.write("*---\n")
  f.write("*  Self Shielding calculation\n")
  f.write("*---\n")
  f.write("LIBRARY2 := USS: LIBRARY TRACK1 :: \n")
  f.write("  EDIT 0\n")
  f.write("  PASS 2\n")
  f.write("  NOCO\n")
  f.write("  ARM\n")
  f.write(";\n\n")

  f.write("*---\n")
  f.write("*  Multigroup Flux Calculation\n")
  f.write("*---\n")
  f.write(" SYS := ASM: LIBRARY2 TRACK1 :: \n")
  f.write("  EDIT 0 ARM PNOR HELI ;\n")
  f.write("\n")
  f.write(" FLUX := FLU: SYS LIBRARY2 TRACK1 ::\n")
  f.write("  EDIT 1 \n")
  f.write("  TYPE K P1 EXTE 100 1E-5 THER 10 1E-5 ;\n")
  f.write("\n")
  f.write("SYS := DELETE: SYS ; \n\n")

  #
  # Write the edition part
  #   
  #
  f.write("*---\n")
  f.write("* Solution for Instant calculations :\n")
  f.write("*---\n\n")

  # Homogenized mixture 1 : F01, K01, C01, B01, G01, J01
  for g in gr:

      f.write("*************\n")
      f.write("*"+str(g)+" Groups *\n")
      f.write("*************\n\n")

      f.write("OUTFUEL := EDI: FLUX LIBRARY2 TRACK1 GEOM ::\n")
      f.write("  EDIT 3\n")
      f.write("  MERG MIX \n")
      f.write("*-Index--#1 2 3 4 5 6 7 8\n")
      i=0
      while i!=10:
          f.write("          "+(str(i)+" ")*8+"\n")
          i=i+1
      f.write("          0 0 0 0 0 0\n\n")
  #  Group condensations :
      if g==295:
	f.write("  COND NONE\n")
      
      elif g==26:
          f.write("  COND 7.408E+06 3.679E+06 6.721E+05 1.111E+05\n")
          f.write("       1.931E+04 3.355E+03 1.585E+03 7.485E+02\n")
          f.write("       2.754E+02 1.301E+02 6.144E+01   29.0\n")
          f.write("       13.70      8.32     5.04       2.38\n")
          f.write("        1.29      0.65     0.35       0.20\n")
          f.write("        0.12      0.08     0.05       0.02\n")
          f.write("        0.01\n")
      
      elif g==23:
	  f.write("  COND 3.679E+06 1.353E+06 5.000E+05 1.110E+05\n")
	  f.write("       6.738E+04 9.118E+03 3.673E+02  4.0\n")
	  f.write("       1.5         1.097    1.045    0.97\n")
	  f.write("       0.85        0.50     0.40     0.35\n")
	  f.write("       0.30        0.25     0.18     0.14\n")
	  f.write("       0.10        0.05\n")
      
      elif g==13:
	  f.write("  COND 1.8315E+05 1.014E+03 1.6745E+01 4.1293\n")
	  f.write("          2.13      1.305      0.79    0.62501\n")
	  f.write("         0.391      0.3145     0.115   5.9E-04\n")

      elif g==10:
	  f.write("  COND 1.8315E+05 1.014E+03 1.6745E+01 4.1293\n")
	  f.write("          2.13       0.79      0.391   0.3145\n")
	  f.write("         0.115   5.9E-04\n")

      elif g==9:
	  f.write("  COND 1.83E+05  9.61E+02     1.76E+01   3.93\n")
	  f.write("          2.38    1.275        0.825     0.13\n")      
      
      elif g==6:
	  f.write("  COND 1.8315E+05   1.6745E+01     2.13   0.62501\n")
	  f.write("       0.115\n")
      
      
      elif g==4:
	  f.write("  COND 1.111E+05 29.0 1.86\n")
      
      elif g==2:
	  f.write("  COND 2.38\n")
      else :
	  print ("This number of groups wasn't expected, go back to the program")
      f.write("  MICR 16 GRAB HE4 O16 NP27 PU38 PU39 PU40\n")
      f.write("          PU41 PU42 AM41 AM42 AM43 C12 SI28 SI29 SI30 \n")
      f.write("  SAVE\n")
      f.write(";\n\n")
      f.write("  Outfuel0 := OUTFUEL ;\n\n")
      f.write("  OUTFUEL := DELETE: OUTFUEL ; \n\n")

  # Homogenized mixture 1 : complete homogenization this time
  for g in gr:

      f.write("*************\n")
      f.write("*"+str(g)+" Groups *\n")
      f.write("*************\n\n")

      f.write("OUTFUEL := EDI: FLUX LIBRARY2 TRACK1 GEOM ::\n")
      f.write("  EDIT 3\n")
      f.write("  MERG MIX \n")
      f.write("*-Index--#1 2 3 4 5 6 7 8\n")
      i=0
      while i!=10:
          f.write("          "+(str(1)+" ")*8+"\n")
          i=i+1
      f.write("          1 1 1 1 1 1\n\n")
  #  Group condensations :
      if g==295:
	f.write("  COND NONE\n")
      
      elif g==26:
          f.write("  COND 7.408E+06 3.679E+06 6.721E+05 1.111E+05\n")
          f.write("       1.931E+04 3.355E+03 1.585E+03 7.485E+02\n")
          f.write("       2.754E+02 1.301E+02 6.144E+01   29.0\n")
          f.write("       13.70      8.32     5.04       2.38\n")
          f.write("        1.29      0.65     0.35       0.20\n")
          f.write("        0.12      0.08     0.05       0.02\n")
          f.write("        0.01\n")
      
      elif g==23:
	  f.write("  COND 3.679E+06 1.353E+06 5.000E+05 1.110E+05\n")
	  f.write("       6.738E+04 9.118E+03 3.673E+02  4.0\n")
	  f.write("       1.5         1.097    1.045    0.97\n")
	  f.write("       0.85        0.50     0.40     0.35\n")
	  f.write("       0.30        0.25     0.18     0.14\n")
	  f.write("       0.10        0.05\n")
      
      elif g==13:
	  f.write("  COND 1.8315E+05 1.014E+03 1.6745E+01 4.1293\n")
	  f.write("          2.13      1.305      0.79    0.62501\n")
	  f.write("         0.391      0.3145     0.115   5.9E-04\n")

      elif g==10:
	  f.write("  COND 1.8315E+05 1.014E+03 1.6745E+01 4.1293\n")
	  f.write("          2.13       0.79      0.391   0.3145\n")
	  f.write("         0.115   5.9E-04\n")

      elif g==9:
	  f.write("  COND 1.83E+05  9.61E+02     1.76E+01   3.93\n")
	  f.write("          2.38    1.275        0.825     0.13\n")      
      
      elif g==6:
	  f.write("  COND 1.8315E+05   1.6745E+01     2.13   0.62501\n")
	  f.write("       0.115\n")
      
      
      elif g==4:
	  f.write("  COND 1.111E+05 29.0 1.86\n")
      
      elif g==2:
	  f.write("  COND 2.38\n")
      else :
	  print ("This number of groups wasn't expected, go back to the program")
      f.write("  MICR 16 GRAB HE4 O16 NP27 PU38 PU39 PU40\n")
      f.write("          PU41 PU42 AM41 AM42 AM43 C12 SI28 SI29 SI30 \n")
      f.write("  SAVE\n")
      f.write(";\n\n")
      f.write("  OutI := OUTFUEL ;\n\n")
      f.write("  OUTFUEL := DELETE: OUTFUEL ; \n\n")

# Beginning of the burnup loop :
  f.write("*----------------------------------------------------\n")
  f.write("* Burnup loop : for first step BURNUP is created\n")
  f.write("*  while for other steps it is modified\n")
  f.write("*----------------------------------------------------\n")
  f.write("WHILE Timei TotalTime <   DO\n")
  f.write("  EVALUATE Timef := Timei Delt + ;\n")
  f.write("  IF Timef Timec = THEN \n")
  f.write("    EVALUATE Iprint := 3 ;\n")
  f.write("  ELSE \n")
  f.write("    EVALUATE Iprint := 1 ;\n")
  f.write("  ENDIF ;\n")

  f.write("  IF Timei 0.0 = THEN \n")
  f.write("    BURNUP LIBRARY2 := EVO: LIBRARY2 FLUX TRACK1 ::\n")
  f.write("       EDIT <<Iprint>> DEPL <<Timei>> <<Timef>> DAY\n")
  f.write("       POWR <<Power>> ; \n")
  f.write("  ELSE\n")
  f.write("     BURNUP LIBRARY2 := EVO: BURNUP LIBRARY2 FLUX TRACK1 ::\n")
  f.write("       EDIT <<Iprint>> NOEX DEPL <<Timei>> <<Timef>> DAY \n")
  f.write("       POWR <<Power>> ; \n")
  f.write("  ENDIF ;\n")

#  f.write("  LIBRARY2 := USS: LIBRARY LIBRARY2 TRACK1  :: \n")
#  f.write("    EDIT 0\n")
#  f.write("    PASS 2\n")
#  f.write("    NOCO\n")
#  f.write("    ARM\n")
#  f.write(";\n\n")

  f.write("*---\n")
  f.write("*  Multigroup Flux Calculation\n")
  f.write("*---\n")
  f.write("  SYS := ASM: LIBRARY2 TRACK1 :: \n")
  f.write("   EDIT 0 ARM PNOR HELI ;\n")
  f.write("\n")
  f.write("  FLUX := FLU: FLUX SYS LIBRARY2 TRACK1 ::\n")
  f.write("   EDIT 1 \n")
  f.write("   TYPE K P1 EXTE 100 1E-5 THER 10 1E-5 ;\n")
  f.write("\n")
  f.write("  SYS := DELETE: SYS ; \n\n")
  f.write("  IF Iprint 3 = THEN \n")
  # Homogenized mixture 1 : F01, K01, C01, B01, G01, J01
  for g in gr:

      f.write("*************\n")
      f.write("*"+str(g)+" Groups *\n")
      f.write("*************\n\n")

      f.write("    OUTFUEL := EDI: FLUX LIBRARY2 TRACK1 GEOM ::\n")
      f.write("      EDIT 3\n")
      f.write("      MERG MIX \n")
      f.write("*-Index------#1 2 3 4 5 6 7 8\n")
      i=0
      while i!=10:
          f.write("              "+(str(i)+" ")*8+"\n")
          i=i+1
      f.write("              0 0 0 0 0 0\n\n")
      
  #  Group condensations :
      if g==295:
	f.write("      COND NONE\n")
      
      elif g==26:
          f.write("      COND 7.408E+06 3.679E+06 6.721E+05 1.111E+05\n")
          f.write("           1.931E+04 3.355E+03 1.585E+03 7.485E+02\n")
          f.write("           2.754E+02 1.301E+02 6.144E+01   29.0\n")
          f.write("           13.70      8.32     5.04       2.38\n")
          f.write("            1.29      0.65     0.35       0.20\n")
          f.write("            0.12      0.08     0.05       0.02\n")
          f.write("            0.01\n")
      
      elif g==23:
	  f.write("      COND 3.679E+06 1.353E+06 5.000E+05 1.110E+05\n")
	  f.write("           6.738E+04 9.118E+03 3.673E+02  4.0\n")
	  f.write("           1.5         1.097    1.045    0.97\n")
	  f.write("           0.85        0.50     0.40     0.35\n")
	  f.write("           0.30        0.25     0.18     0.14\n")
	  f.write("           0.10        0.05\n")
      
      elif g==13:
	  f.write("      COND 1.8315E+05 1.014E+03 1.6745E+01 4.1293\n")
	  f.write("              2.13      1.305      0.79    0.62501\n")
	  f.write("             0.391      0.3145     0.115   5.9E-04\n")

      elif g==10:
	  f.write("      COND 1.8315E+05 1.014E+03 1.6745E+01 4.1293\n")
	  f.write("              2.13       0.79      0.391   0.3145\n")
	  f.write("             0.115   5.9E-04\n")

      elif g==9:
	  f.write("      COND 1.83E+05  9.61E+02     1.76E+01   3.93\n")
	  f.write("              2.38    1.275        0.825     0.13\n")      
      
      elif g==6:
	  f.write("      COND 1.8315E+05   1.6745E+01     2.13   0.62501\n")
	  f.write("           0.115\n")
      
      
      elif g==4:
	  f.write("      COND 1.111E+05 29.0 1.86\n")
      
      elif g==2:
	  f.write("      COND 2.38\n")
      else :
	  print ("This number of groups wasn't expected, go back to the program")
      f.write("  MICR 16 GRAB HE4 O16 NP27 PU38 PU39 PU40\n")
      f.write("          PU41 PU42 AM41 AM42 AM43 C12 SI28 SI29 SI30\n")
      f.write("      SAVE ;\n")
      
      f.write("    IF I 1 = THEN\n")
      f.write("      Outfuel1 := OUTFUEL ;\n")
      f.write("      OUTFUEL := DELETE: OUTFUEL ;\n")
      f.write("    ENDIF ;\n")
      f.write("    IF I 2 = THEN\n")
      f.write("      Outfuel2 := OUTFUEL ;\n")
      f.write("      OUTFUEL := DELETE: OUTFUEL ;\n")
      f.write("    ENDIF ;\n")
      f.write("    IF I 3 = THEN\n")
      f.write("      Outfuel3 := OUTFUEL ;\n")
      f.write("      OUTFUEL := DELETE: OUTFUEL ;\n")
      f.write("    ENDIF ;\n")
      f.write("    EVALUATE I := I 1 + ;\n")
      f.write("  ENDIF ;\n")
      f.write("*-------------------------------------------------------\n")
      f.write("*  Change delta t for burnup, final time and power if required\n")
      f.write("*--------------------------------------------------------\n")
      f.write("  IF Timef Timec = THEN\n")
      f.write("    IF Timec 500.0 = THEN\n")
      f.write("      EVALUATE Delt Timec := 100.0 1000.0 ;\n")
      f.write("    ENDIF ;\n")
      f.write("    IF Timec 50.0 = THEN\n")
      f.write("      EVALUATE Delt Timec := 50.0 500.0 ;\n")
      f.write("    ENDIF ;\n")
      f.write("  ENDIF ;\n")
      f.write("  EVALUATE Timei := Timef ;\n")
      f.write("ENDWHILE ;\n\n")

      f.write("* Termination of the script : cleaning and end.\n\n")
  # Homogenized mixture 1 : complete homogenization this time
      for g in gr:

          f.write("*************\n")
          f.write("*"+str(g)+" Groups *\n")
          f.write("*************\n\n")

          f.write("OUTFUEL := EDI: FLUX LIBRARY2 TRACK1 GEOM ::\n")
          f.write("  EDIT 3\n")
          f.write("  MERG MIX \n")
          f.write("*-Index--#1 2 3 4 5 6 7 8\n")
          i=0
          while i!=10:
              f.write("          "+(str(1)+" ")*8+"\n")
              i=i+1
          f.write("          1 1 1 1 1 1\n\n")
  #  Group condensations :
          if g==295:
	    f.write("  COND NONE\n")
      
          elif g==26:
              f.write("  COND 7.408E+06 3.679E+06 6.721E+05 1.111E+05\n")
              f.write("       1.931E+04 3.355E+03 1.585E+03 7.485E+02\n")
              f.write("       2.754E+02 1.301E+02 6.144E+01   29.0\n")
              f.write("       13.70      8.32     5.04       2.38\n")
              f.write("        1.29      0.65     0.35       0.20\n")
              f.write("        0.12      0.08     0.05       0.02\n")
              f.write("        0.01\n")
      
          elif g==23:
	      f.write("  COND 3.679E+06 1.353E+06 5.000E+05 1.110E+05\n")
              f.write("       6.738E+04 9.118E+03 3.673E+02  4.0\n")
              f.write("       1.5         1.097    1.045    0.97\n")
	      f.write("       0.85        0.50     0.40     0.35\n")
	      f.write("       0.30        0.25     0.18     0.14\n")
	      f.write("       0.10        0.05\n")
      
          elif g==13:
	      f.write("  COND 1.8315E+05 1.014E+03 1.6745E+01 4.1293\n")
	      f.write("          2.13      1.305      0.79    0.62501\n")
	      f.write("         0.391      0.3145     0.115   5.9E-04\n")

          elif g==10:
	      f.write("  COND 1.8315E+05 1.014E+03 1.6745E+01 4.1293\n")
	      f.write("          2.13       0.79      0.391   0.3145\n")
	      f.write("         0.115   5.9E-04\n")

          elif g==9:
	      f.write("  COND 1.83E+05  9.61E+02     1.76E+01   3.93\n")
	      f.write("          2.38    1.275        0.825     0.13\n")      
      
          elif g==6:
	      f.write("  COND 1.8315E+05   1.6745E+01     2.13   0.62501\n")
	      f.write("       0.115\n")
      
      
          elif g==4:
	      f.write("  COND 1.111E+05 29.0 1.86\n")
      
          elif g==2:
	      f.write("  COND 2.38\n")
          else :
	      print ("This number of groups wasn't expected, go back to the program")
          f.write("  MICR 16 GRAB HE4 O16 NP27 PU38 PU39 PU40\n")
          f.write("          PU41 PU42 AM41 AM42 AM43 C12 SI28 SI29 SI30 \n")
          f.write("  SAVE\n")
          f.write(";\n\n")
          f.write("  OutF := OUTFUEL ;\n\n")
          f.write("  OUTFUEL := DELETE: OUTFUEL ; \n\n")

      f.write("TRACK1  := DELETE: TRACK1 ; \n\n")
      f.write("LIBRARY := DELETE: LIBRARY ; \n")
      f.write("LIBRARY2 := DELETE: LIBRARY2 ; \n")
      f.write("BURNUP := DELETE: BURNUP ; \n")

      f.write("END: ;\n")
      f.write('QUIT "LIST" .\n')

  f.close()
  print "End of DragSB.py with : "+str(Nbg)+" groups."
# make it run as a script

if __name__ == "__main__":
    import sys
    DragSB(int(sys.argv[1]))

#end

