#! /usr/bin/env python 
# -*- coding: utf-8 -*-
###################################################################################
# Program   : DragSupCell
# Author    : Vincent Descotes, 7/07/2010 
# Purpose   : create a file in 'pwd' where all mixtures are numbered 
#             for the supercell problem.
# ATTENTION : you need to provide manually the good number of cells in GEO:
#             (by modifying this script, line 174). At least, verify it.
# Input     : Nbg : int : number of groups for the condensation
# Output    : file supercell_XXXgr_33r.x2m.txt in current directory. Ready to run.
###################################################################################
def DragSupCell(Nbg):
  import os
  import numpy
  #Number of fuel cells FXX
  NF = 7+8
  #Number of coolant cells CXX
  NC = 7
  #Number of small coolant cells KXX
  NK = 7
  #Number of normal graphite cells GXX
  NG = 13
  #Number of graphite J cells JXX
  NJ = 13
  #Number of burnable poison cells BXX
  NB = 7

  #Count total number of mixtures
  NTOT = NF*2+NC+NK+NG+NJ+NB

  # Number of groups for the condensation :
  gr=[Nbg]

  #Opening file supercell_XXXgr_33r.x2m for writing
  INPTPATH = os.getcwd()
  f = open(INPTPATH+'/Mike_SupCell_c18_'+str(gr[0])+'gr_33r.x2m', 'w')
  # Opening file with the cell repartition (output of buildsupercell_n18_33r.f)
  fs = open(INPTPATH+'/list', 'r') 

  # Header in DRAGON
  f.write("*--------------------------------------------------------------------\n")
  f.write("* NGNP-VHTR Supercell Lattice calculation\n")
  f.write("* Fresh fuel TRU loading\n")
  f.write("* Author : V. Descotes\n")
  f.write("* Core corner block(6,1), no BP, no CR.\n")
  f.write("* JEFF3.1.0\n")  
  f.write("* SHEM295 Group Structure\n\n") 
  f.write("*--------------------------------------------------------------------\n")
  f.write("* Define variables \n")
  f.write("*    Burnup parameters :\n")
  f.write("*    a) Power = 600.0 MW.tonne^-1 = 600.0 kW.kg^-1 \n")
  f.write("*    b) Burnup time intervals Delt :\n")
  f.write("*        = 10 days for 0 to 50 days\n")
  f.write("*        = 50 days for 50 to 500 days\n")
  f.write("*        = 100 days for 500 to 1000 days\n")
  f.write("*    c) Editing time Timec\n")
  f.write("*        = 0.0 50.0 500.0 and 1000.0 days\n")
  f.write("*    d) Burnup control time variables\n")
  f.write("*        Timei = initial time \n")
  f.write("*        Timef = final time \n")
  f.write("*        TotalTime = Final time reached \n")
  f.write("*    e) Print variable Iprint \n")
  f.write("*         = 1 reduced print\n")
  f.write("*         = 3 full print \n")
  f.write("*    f) Count the number of output files : I (integer) \n")
  f.write("*--------------------------------------------------------------------\n*\n")
  f.write("*--------------------------------------------------------------------\n")  
  f.write("*  Define variables used\n")
  f.write("*-------------------------------------------------------------------- \n")
  f.write("REAL\n")
  f.write("  Power Delt Timec Timei Timef TotalTime :=\n")
  f.write("  600.0 10.0 50.0   0.0    0.0  1000.0 ;\n")
  f.write("INTEGER\n")
  f.write("  Iprint I  := 1 1 ;\n")
  f.write("*--------------------------------------------------------------------\n")  
  f.write("*  Define STRUCTURES and MODULES used\n")
  f.write("*-------------------------------------------------------------------- \n")

  # Structures and modules in DRAGON

  f.write('LINKED_LIST \n')
  f.write('   LIBRARY GEOM SYS FLUX CPO\n')
  f.write("   OUT BURNUP ;\n\n")

  f.write("XSM_FILE TRACK1 ;\n")

  f.write("SEQ_ASCII Multicompo Out0 Out1 Out2 Out3 OutI OutF ;\n")

  f.write("MODULE\n")
  f.write("  GEO: SYBILT: LIB: ASM: FLU: EDI: DELETE: END: NCR: EVO: ;\n\n")

  # Initialization of the Compo LCM objet
  f.write("*--------------------------------------------------------------------\n") 
  f.write("* INITIALIZATION OF THE COMPO LCM OBJECTS\n")
  f.write("*--------------------------------------------------------------------\n\n")

  f.write("CPO := Multicompo ;\n\n")

  # Association of a mixture number to each element of each block
  f.write("*--------------------------------------------------------------------\n")
  f.write("* ENTER DATA INTO COMPO LCM OBJECT \n")
  f.write("*--------------------------------------------------------------------\n\n")
    
  f.write('LIBRARY := NCR: CPO ::\n')
  s=str(NTOT)
  f.write('EDIT 0 NMIX '+str(NTOT)+'\n')

  f.write("   COMPO CPO 'F'\n")
  f.write("\n* First mixture for the fuel pellet\n")
  i=1
  while i<=NF:
      s=str(i)
      f.write('   MIX  ')
      f.write(s)
      f.write(' FROM 1 ENDMIX\n')
      i=i+1
  f.write("\n* Second mixture for helium + graphite surrounding the fuel pellet\n")
  j=1
  while j<=NF:
      s=str(i)
      f.write('   MIX  ')
      f.write(s)
      f.write(' FROM 2 ENDMIX\n')
      i=i+1
      j=j+1

  f.write("\n   COMPO CPO 'K'\n")
  f.write("\n* Mixture for small coolant\n")
  j=1
  while j<=NK:
      s=str(i)
      f.write('   MIX  ')
      f.write(s)
      f.write(' FROM 1 ENDMIX\n')
      i=i+1
      j=j+1

  f.write("\n   COMPO CPO 'C'\n")
  f.write("\n* Mixture for large coolant\n")
  j=1
  while j<=NC:
      s=str(i)
      f.write('   MIX  ')
      f.write(s)
      f.write(' FROM 1 ENDMIX\n')
      i=i+1
      j=j+1

  # Mixtures for B cells --> graphite for the moment
  f.write("\n   COMPO CPO 'G'\n")
  f.write("\n* Mixture for the burnable poison cells (graphite here)\n")
  j=1
  while j<=NB:
      s=str(i)
      f.write('   MIX  ')
      f.write(s)
      f.write(' FROM 1 ENDMIX\n')
      i=i+1
      j=j+1

  f.write("\n   COMPO CPO 'G'\n\n")
  f.write("* Mixture for the full graphite cells\n")
  j=1
  while j<=NG:
      s=str(i)
      f.write('   MIX  ')
      f.write(s)
      f.write(' FROM 1 ENDMIX\n')
      i=i+1
      j=j+1

  f.write("\n   COMPO CPO 'J'\n")
  f.write("\n* Mixture for the J-cells (graphite)\n")
  j=1
  while j<=NJ:
      s=str(i)
      f.write('   MIX  ')
      f.write(s)
      f.write(' FROM 1 \n')
      f.write('    MICRO ONLY\n')
      f.write('    GRAB  9.486753785E-02 \n')
      f.write('   ENDMIX\n')
      i=i+1
      j=j+1

  f.write(";")
  f.write("\n")
  f.write("\n")
  #
  # Write the GEO part
  #

  f.write("*--------------------------------------------------------\n")
  f.write("*             SUPERCELL SPECIFICATION\n")
  f.write("*--------------------------------------------------------\n")
  f.write("* ----\n")
  f.write("* F = Fuel cell\n")
  f.write("* C = coolant hole cell (large)\n")
  f.write("* K = coolant hole cell (small)\n")
  f.write("* G = Full density graphite cell\n")
  f.write("* J = Reduced/increased density graphite cell\n")
  f.write("* ----\n\n")

  f.write("GEOM := GEO: :: HEX 3367\n")
  f.write("  EDIT 0\n")
  f.write("  HBC COMPLETE REFL\n")
  f.write("  CELL\n")
  # Copy the file list that contains the cell repartition.
  txt = "1"
  while txt != "":
    txt = fs.readline()
    f.write(txt)
  fs.close() # The "list" file is now closed.

  #
  # Write the subgeometries
  #
  f.write("*\n")
  f.write("*--------------------------------------------------------------------\n")
  f.write("* Cell Definitions\n")
  f.write("*--------------------------------------------------------------------\n")
  f.write("*\n")

  f.write("*  Fuel Cell FXX --------------------------- \n")
  i=1
  j=1
  while j<=NF-8:
      if j==1:
          c=0
          while c !=9:
              f.write(" ::: F"+str(c)+str(j)+" := GEO: HEXCEL 1\n")
              f.write("     SIDE 1.08542 \n")
              f.write("     RADIUS 0.0 0.6225\n")
              f.write("     SECT -1 \n")
              f.write("     MIX "+(str(i)+" ")*6+"\n")
              f.write("         "+(str(i+NF)+" ")*6+" ;\n")
              c=c+1
              i=i+1
          j=j+1
      elif 1<j<10:
	  f.write(" ::: F0"+str(j)+" := GEO: HEXCEL 1\n")
          f.write("     SIDE 1.08542 \n")
          f.write("     RADIUS 0.0 0.6225\n")
          f.write("     SECT -1 \n")
          f.write("     MIX "+(str(i)+" ")*6+"\n")
          f.write("         "+(str(i+NF)+" ")*6+" ;\n")
          j=j+1
          i=i+1
      else:
	  f.write(" ::: F"+str(j)+" := GEO: HEXCEL 1\n")
          f.write("     SIDE 1.08542 \n")
          f.write("     RADIUS 0.0 0.6225\n")
          f.write("     SECT -1 \n")
          f.write("     MIX "+(str(i)+" ")*6+"\n")
          f.write("         "+(str(i+NF)+" ")*6+" ;\n")
          j=j+1
          i=i+1

  i=i+NF # pour passer les deux autres rangees concernant le fuel.

  f.write("*  Small coolant Hole KXX ------------------  \n")
  j=1
  while j<=NK:
      if j<10:
	  f.write(" ::: K0"+str(j)+" := GEO: HEXCEL 3\n")
      else:
	  f.write(" ::: K"+str(j)+" := GEO: HEXCEL 3\n")
      f.write("     SIDE 1.08542 \n")
      f.write("     RADIUS 0.0 0.207 0.415 0.6225\n")
      f.write("     SECT -1 \n")
      f.write("     MIX "+(str(i)+" ")*6+"\n")
      f.write("         "+(str(i)+" ")*6+"\n")
      f.write("         "+(str(i)+" ")*6+"\n")
      f.write("         "+(str(i)+" ")*6+" ;\n")
      j=j+1
      i=i+1


  f.write("*  Large Coolant Hole CXX ------------------\n")
  j=1
  while j<=NC:
      if j<10:
	  f.write(" ::: C0"+str(j)+" := GEO: HEXCEL 3\n")
      else:
	  f.write(" ::: C"+str(j)+" := GEO: HEXCEL 3\n")
      f.write("     SIDE 1.08542 \n")
      f.write("     RADIUS 0.0 0.207 0.415 0.6225\n")
      f.write("     SECT -1 \n")
      f.write("     MIX "+(str(i)+" ")*6+"\n")
      f.write("         "+(str(i)+" ")*6+"\n")
      f.write("         "+(str(i)+" ")*6+"\n")
      f.write("         "+(str(i)+" ")*6+" ;\n")
      j=j+1
      i=i+1

  f.write("*  Burnable poison cells BXX (GRA here) ---- \n")
  j=1
  while j<=NB:
      if j<10:
	  f.write(" ::: B0"+str(j)+" := GEO: HEXCEL 3\n")
      else:
	  f.write(" ::: B"+str(j)+" := GEO: HEXCEL 3\n")
      f.write("     SIDE 1.08542 \n")
      f.write("     RADIUS 0.0 0.207 0.415 0.6225\n")
      f.write("     SECT -1 \n")
      f.write("     MIX "+(str(i)+" ")*6+"\n")
      f.write("         "+(str(i)+" ")*6+"\n")
      f.write("         "+(str(i)+" ")*6+"\n")
      f.write("         "+(str(i)+" ")*6+" ;\n")
      j=j+1
      i=i+1

  f.write("*  Full Density Grapite GXX ---------------- \n")
  j=1
  while j<=NG:
      if (j)<10:
	  f.write(" ::: G0"+str(j)+" := GEO: HEXCEL 3\n")
	  f.write("     SIDE 1.08542 \n")
	  f.write("     RADIUS 0.0 0.207 0.415 0.6225\n")
	  f.write("     SECT -1 \n")
	  f.write("     MIX "+(str(i)+" ")*6+"\n")
	  f.write("         "+(str(i)+" ")*6+"\n")
	  f.write("         "+(str(i)+" ")*6+"\n")
	  f.write("         "+(str(i)+" ")*6+" ;\n")
      else:
	  f.write(" ::: G"+str(j)+" := GEO: HEXCEL 3\n")
	  f.write("     SIDE 1.08542 \n")
	  f.write("     RADIUS 0.0 0.207 0.415 0.6225\n")
	  f.write("     SECT -1 \n")
	  f.write("     MIX "+(str(i)+" ")*6+"\n")
	  f.write("         "+(str(i)+" ")*6+"\n")
	  f.write("         "+(str(i)+" ")*6+"\n")
	  f.write("         "+(str(i)+" ")*6+" ;\n")
      j=j+1
      i=i+1

  f.write("*  Reduced/increased Density Graphite JXX -- \n")
  j=1
  while j<=NJ:
      if (j)<10:
	  f.write(" ::: J0"+str(j)+" := GEO: HEXCEL 3\n")
	  f.write("     SIDE 1.08542 \n")
	  f.write("     RADIUS 0.0 0.207 0.415 0.6225\n")
	  f.write("     SECT -1 \n")
	  f.write("     MIX "+(str(i)+" ")*6+"\n")
	  f.write("         "+(str(i)+" ")*6+"\n")
	  f.write("         "+(str(i)+" ")*6+"\n")
	  f.write("         "+(str(i)+" ")*6+" ;\n")
      else:
	  f.write(" ::: J"+str(j)+" := GEO: HEXCEL 3\n")
	  f.write("     SIDE 1.08542 \n")
	  f.write("     RADIUS 0.0 0.207 0.415 0.6225\n")
	  f.write("     SECT -1 \n")
	  f.write("     MIX "+(str(i)+" ")*6+"\n")
	  f.write("         "+(str(i)+" ")*6+"\n")
	  f.write("         "+(str(i)+" ")*6+"\n")
	  f.write("         "+(str(i)+" ")*6+" ;\n")
      j=j+1
      i=i+1

  f.write(";\n\n\n")

  #
  # Write the tracking and flux calculation part
  #

  f.write("*--------------------------------------------------------------------\n")
  f.write("*  Use SYBILT, ASM and FLU for flux solution\n")
  f.write("*--------------------------------------------------------------------\n\n")
  f.write("***\n")
  f.write("* Tracking SYBILT\n") 
  f.write("***\n")
  f.write("TRACK1 := SYBILT: GEOM ::\n")
  f.write("    EDIT 1\n")
  f.write("    MAXR 800000\n")
  f.write("    MAXZ 990000\n")
  f.write("    QUA2 4 6  \n")
  f.write("    DP00\n")
  f.write(";\n")      

  f.write("*---\n")
  f.write("*  Multigroup Flux Calculation\n")
  f.write("*---\n")
  f.write(" SYS := ASM: LIBRARY TRACK1 :: \n")
  f.write("  EDIT 0 ARM PNOR HELI ;\n")
  f.write("\n")
  f.write(" FLUX := FLU: SYS LIBRARY TRACK1 ::\n")
  f.write("  EDIT 2 \n")
  f.write("  TYPE K P1 EXTE 100 1E-5 THER 10 1E-5 ;\n")

  f.write("\n")
  f.write("SYS := DELETE: SYS ; \n\n")

  #
  # Write the first part of EDI:
  #   
  #
  f.write("*---\n")
  f.write("* Solution for Instant calculation :\n")
  f.write("* -> homogenize all regions of the central block\n")
  f.write("*---\n\n")

  f.write('*---\n')
  f.write('* Mixtures merge for Instant :\n')
  f.write('* Fuel cell 01 merged with gradient\n')
  f.write('*---\n\n')

  # Homogenized mixture 1 : F11, F21,F31,F41,F51,F61,F71,F81
  for g in gr:

      f.write("*************\n")
      f.write("*"+str(g)+" Groups *\n")
      f.write("*************\n\n")

      f.write("OUT := EDI: FLUX LIBRARY TRACK1 GEOM ::\n")
      f.write("   EDIT 3\n")
      f.write("   MERGE MIX\n")
      f.write("*1 2 3 4 5 6 7 8 9 10\n")
      k=1
      f.write("* F mixtures : fuel pellet\n")
      while k<=NF:
          if 1<k<10:
	      f.write(" "+str(k-1))
	  else:
	      f.write(" 0")
	      if k==10:
		  f.write("\n")
	  k=k+1
      f.write("\n")
      k=1
      f.write("* F mixtures : helium and graphite surrounding fuel pellet\n")
      while k<=NF:
          if 1<k<10:
	      f.write(" "+str(k-1))
	  else:
	      f.write(" 0")
	      if k==10:
		  f.write("\n")
	  k=k+1
      f.write("\n")
      k=1
      f.write("* K mixtures\n")
      while k<=NK:
	  if k==1:
	      f.write(" 0")
	      if k==10:
		  f.write("\n")
	  else:
	      f.write(" 0")
	      if k==10:
		  f.write("\n")
	  k=k+1
      f.write("\n")
      k=1
      f.write("* C mixtures\n")
      while k<=NC:
	  if k==1:
	      f.write(" 0")
	      if k==10:
		  f.write("\n")
	  else:
	      f.write(" 0")
	      if k==10:
		  f.write("\n")
	  k=k+1
      f.write("\n")
      k=1
      f.write("* B mixtures\n")
      while k<=NB:
	  if k==1:
	      f.write(" 0")
	      if k==10:
		  f.write("\n")
	  else:
	      f.write(" 0")
	      if k==10:
		  f.write("\n")
	  k=k+1
      f.write("\n")
      k=1
      f.write("* G mixtures\n")
      while k<=NG:
	  if k==1:
	      f.write(" 0")
	      if k==10:
		  f.write("\n")
	  else:
	      f.write(" 0")
	      if k==10:
		  f.write("\n")
	  k=k+1
      f.write("\n")
      k=1
      f.write("* J mixtures\n")
      while k<=NJ:
	  if k==1:
	      f.write(" 0")
	      if k==10:
		  f.write("\n")
	  else:
	      f.write(" 0")
	      if k==10:
		  f.write("\n")
	  k=k+1

      f.write("\n")
  #  Group condensations :
      if g==295:
	f.write("  COND NONE\n")
      
      elif g==26:
          f.write("  COND 7.408E+06 3.679E+06 6.721E+05 1.111E+05\n")
          f.write("       1.931E+04 3.355E+03 1.585E+03 7.485E+02\n")
          f.write("       2.754E+02 1.301E+02 6.144E+01   29.0\n")
          f.write("       13.70      8.32     5.04       2.38\n")
          f.write("        1.29      0.65     0.35       0.20\n")
          f.write("        0.12      0.08     0.05       0.02\n")
          f.write("        0.01\n")
      
      elif g==23:
	  f.write("  COND 3.679E+06 1.353E+06 5.000E+05 1.110E+05\n")
	  f.write("       6.738E+04 9.118E+03 3.673E+02  4.0\n")
	  f.write("       1.5         1.097    1.045    0.97\n")
	  f.write("       0.85        0.50     0.40     0.35\n")
	  f.write("       0.30        0.25     0.18     0.14\n")
	  f.write("       0.10        0.05\n")
      
      elif g==13:
	  f.write("  COND 1.8315E+05 1.014E+03 1.6745E+01 4.1293\n")
	  f.write("          2.13      1.305      0.79    0.62501\n")
	  f.write("         0.391      0.3145     0.115   5.9E-04\n")

      elif g==10:
	  f.write("  COND 1.8315E+05 1.014E+03 1.6745E+01 4.1293\n")
	  f.write("          2.13       0.79     0.391    0.3145 \n")
	  f.write("          0.115     5.9E-04\n")

      elif g==9:
	  f.write("  COND 1.83E+05    9.61E+02   1.76E+01  3.93\n")
	  f.write("          2.38       1.275     0.825    0.13 \n")      
      
      elif g==6:
	  f.write("  COND 1.8315E+05   1.6745E+01     2.13   0.62501\n")
	  f.write("       0.115\n")
      
      elif g==4:
	  f.write("  COND 1.111E+05 29.0 1.86\n")
      
      elif g==2:
	  f.write("  COND 2.38\n")
      else :
	  print ("This number of groups wasn't expected, go back to the program")
          raise NameError
      f.write("  MICR 16 GRAB HE4 O16 NP27 PU38 PU39 PU40\n")
      f.write("          PU41 PU42 AM41 AM42 AM43 C12 SI28 SI29 SI30 \n")
      f.write("  SAVE\n")
      f.write(";\n\n")
      f.write("Out0 := OUT ;\n")
      f.write("OUT := DELETE: OUT ;\n\n")



  f.write('*---\n')
  f.write('* Mixtures merge for Instant :\n')
  f.write('* Fuel cell 01 merged completely\n')
  f.write('*---\n\n')

  # Homogenized mixture 1 : F11, F21,F31,F41,F51,F61,F71,F81
  for g in gr:

      f.write("*************\n")
      f.write("*"+str(g)+" Groups *\n")
      f.write("*************\n\n")

      f.write("OUT := EDI: FLUX LIBRARY TRACK1 GEOM ::\n")
      f.write("   EDIT 3\n")
      f.write("   MERGE MIX\n")
      f.write("*1 2 3 4 5 6 7 8 9 10\n")
      k=1
      f.write("* F mixtures : fuel pellet\n")
      while k<=NF:
          if 0<k<10:
	      f.write(" "+str(1))
	  else:
	      f.write(" 0")
	      if k==10:
		  f.write("\n")
	  k=k+1
      f.write("\n")
      k=1
      f.write("* F mixtures : helium and graphite surrounding fuel pellet\n")
      while k<=NF:
          if 0<k<10:
	      f.write(" "+str(1))
	  else:
	      f.write(" 0")
	      if k==10:
		  f.write("\n")
	  k=k+1
      f.write("\n")
      k=1
      f.write("* K mixtures\n")
      while k<=NK:
	  if k==1:
	      f.write(" 1")
	      if k==10:
		  f.write("\n")
	  else:
	      f.write(" 0")
	      if k==10:
		  f.write("\n")
	  k=k+1
      f.write("\n")
      k=1
      f.write("* C mixtures\n")
      while k<=NC:
	  if k==1:
	      f.write(" 1")
	      if k==10:
		  f.write("\n")
	  else:
	      f.write(" 0")
	      if k==10:
		  f.write("\n")
	  k=k+1
      f.write("\n")
      k=1
      f.write("* B mixtures\n")
      while k<=NB:
	  if k==1:
	      f.write(" 1")
	      if k==10:
		  f.write("\n")
	  else:
	      f.write(" 0")
	      if k==10:
		  f.write("\n")
	  k=k+1
      f.write("\n")
      k=1
      f.write("* G mixtures\n")
      while k<=NG:
	  if k==1:
	      f.write(" 1")
	      if k==10:
		  f.write("\n")
	  else:
	      f.write(" 0")
	      if k==10:
		  f.write("\n")
	  k=k+1
      f.write("\n")
      k=1
      f.write("* J mixtures\n")
      while k<=NJ:
	  if k==1:
	      f.write(" 1")
	      if k==10:
		  f.write("\n")
	  else:
	      f.write(" 0")
	      if k==10:
		  f.write("\n")
	  k=k+1

      f.write("\n")
  #  Group condensations :
      if g==295:
	f.write("  COND NONE\n")
      
      elif g==26:
          f.write("  COND 7.408E+06 3.679E+06 6.721E+05 1.111E+05\n")
          f.write("       1.931E+04 3.355E+03 1.585E+03 7.485E+02\n")
          f.write("       2.754E+02 1.301E+02 6.144E+01   29.0\n")
          f.write("       13.70      8.32     5.04       2.38\n")
          f.write("        1.29      0.65     0.35       0.20\n")
          f.write("        0.12      0.08     0.05       0.02\n")
          f.write("        0.01\n")
      
      elif g==23:
	  f.write("  COND 3.679E+06 1.353E+06 5.000E+05 1.110E+05\n")
	  f.write("       6.738E+04 9.118E+03 3.673E+02  4.0\n")
	  f.write("       1.5         1.097    1.045    0.97\n")
	  f.write("       0.85        0.50     0.40     0.35\n")
	  f.write("       0.30        0.25     0.18     0.14\n")
	  f.write("       0.10        0.05\n")
      
      elif g==13:
	  f.write("  COND 1.8315E+05 1.014E+03 1.6745E+01 4.1293\n")
	  f.write("          2.13      1.305      0.79    0.62501\n")
	  f.write("         0.391      0.3145     0.115   5.9E-04\n")

      elif g==10:
	  f.write("  COND 1.8315E+05 1.014E+03 1.6745E+01 4.1293\n")
	  f.write("          2.13       0.79     0.391    0.3145 \n")
	  f.write("          0.115     5.9E-04\n")

      elif g==9:
	  f.write("  COND 1.83E+05    9.61E+02   1.76E+01  3.93\n")
	  f.write("          2.38       1.275     0.825    0.13 \n")      
      
      elif g==6:
	  f.write("  COND 1.8315E+05   1.6745E+01     2.13   0.62501\n")
	  f.write("       0.115\n")
      
      elif g==4:
	  f.write("  COND 1.111E+05 29.0 1.86\n")
      
      elif g==2:
	  f.write("  COND 2.38\n")
      else :
	  print ("This number of groups wasn't expected, go back to the program")
          raise NameError
      f.write("  MICR 16 GRAB HE4 O16 NP27 PU38 PU39 PU40\n")
      f.write("          PU41 PU42 AM41 AM42 AM43 C12 SI28 SI29 SI30 \n")
      f.write("  SAVE\n")
      f.write(";\n\n")
      f.write("OutI := OUT ;\n")
      f.write("OUT := DELETE: OUT ;\n\n")



### Beginning of the burnup loop : ###
  f.write("*----------------------------------------------------\n")
  f.write("* Burnup loop : for first step BURNUP is created\n")
  f.write("*  while for other steps it is modified\n")
  f.write("*----------------------------------------------------\n")
  f.write("WHILE Timei TotalTime <   DO\n")
  f.write("  EVALUATE Timef := Timei Delt + ;\n")
  f.write("  IF Timef Timec = THEN \n")
  f.write("    EVALUATE Iprint := 3 ;\n")
  f.write("  ELSE \n")
  f.write("    EVALUATE Iprint := 1 ;\n")
  f.write("  ENDIF ;\n")

  f.write("  IF Timei 0.0 = THEN \n")
  f.write("    BURNUP LIBRARY := EVO: LIBRARY FLUX TRACK1 ::\n")
  f.write("       EDIT <<Iprint>> DEPL <<Timei>> <<Timef>> DAY\n")
  f.write("       POWR <<Power>> ; \n")

  f.write("  ELSE\n")
  f.write("     BURNUP LIBRARY := EVO: BURNUP LIBRARY FLUX TRACK1 ::\n")
  f.write("       EDIT <<Iprint>> NOEX DEPL <<Timei>> <<Timef>> DAY \n")
  f.write("       POWR <<Power>> ; \n")

  f.write("  ENDIF ;\n")

  f.write("*---\n")
  f.write("*  Multigroup Flux Calculation\n")
  f.write("*---\n")
  f.write("  SYS := ASM: LIBRARY TRACK1 :: \n")
  f.write("   EDIT 0 ARM PNOR HELI ;\n")
  f.write("\n")
  f.write("  FLUX := FLU: FLUX SYS LIBRARY TRACK1 ::\n")
  f.write("   EDIT 1 \n")
  f.write("   TYPE K P1 EXTE 100 1E-5 THER 10 1E-5 ;\n")
  f.write("\n")
  f.write("  SYS := DELETE: SYS ; \n\n")
  f.write("  IF Iprint 3 = THEN \n")
  # Homogenized mixture 1 : F11, F21,F31,F41,F51,F61,F71,F81
  for g in gr:

      f.write("*************\n")
      f.write("*"+str(g)+" Groups *\n")
      f.write("*************\n\n")

      f.write("    OUT := EDI: FLUX LIBRARY TRACK1 GEOM ::\n")
      f.write("       EDIT 3\n")
      f.write("       MERGE MIX\n")
      f.write("*    1 2 3 4 5 6 7 8 9 10\n")
      k=1
      f.write("*     F mixtures : fuel pellet\n    ")
      while k<=NF:
          if 1<k<10:
	      f.write(" "+str(k-1))
	  else:
	      f.write(" 0")
	      if k==10:
		  f.write("\n    ")
	  k=k+1
      f.write("\n")
      k=1
      f.write("*     F mixtures : helium and graphite surrounding fuel pellet\n    ")
      while k<=NF:
          if 1<k<10:
	      f.write(" "+str(k-1))
	  else:
	      f.write(" 0")
	      if k==10:
		  f.write("\n    ")
	  k=k+1
      f.write("\n")
      k=1
      f.write("*     K mixtures\n    ")
      while k<=NK:
	  if k==1:
	      f.write(" 0")
	      if k==10:
		  f.write("\n    ")
	  else:
	      f.write(" 0")
	      if k==10:
		  f.write("\n    ")
	  k=k+1
      f.write("\n")
      k=1
      f.write("*     C mixtures\n    ")
      while k<=NC:
	  if k==1:
	      f.write(" 0")
	      if k==10:
		  f.write("\n    ")
	  else:
	      f.write(" 0")
	      if k==10:
		  f.write("\n    ")
	  k=k+1
      f.write("\n")
      k=1
      f.write("*     B mixtures\n    ")
      while k<=NB:
	  if k==1:
	      f.write(" 0")
	      if k==10:
		  f.write("\n    ")
	  else:
	      f.write(" 0")
	      if k==10:
		  f.write("\n    ")
	  k=k+1
      f.write("\n")
      k=1
      f.write("*     G mixtures\n    ")
      while k<=NG:
	  if k==1:
	      f.write(" 0")
	      if k==10:
		  f.write("\n    ")
	  else:
	      f.write(" 0")
	      if k==10:
		  f.write("\n    ")
	  k=k+1
      f.write("\n")
      k=1
      f.write("*     J mixtures\n    ")
      while k<=NJ:
	  if k==1:
	      f.write(" 0")
	      if k==10:
		  f.write("\n    ")
	  else:
	      f.write(" 0")
	      if k==10:
		  f.write("\n    ")
	  k=k+1

      f.write("\n")
  #  Group condensations :
      if g==295:
	f.write("      COND NONE\n")
      
      elif g==26:
          f.write("      COND 7.408E+06 3.679E+06 6.721E+05 1.111E+05\n")
          f.write("           1.931E+04 3.355E+03 1.585E+03 7.485E+02\n")
          f.write("           2.754E+02 1.301E+02 6.144E+01   29.0\n")
          f.write("           13.70      8.32     5.04       2.38\n")
          f.write("            1.29      0.65     0.35       0.20\n")
          f.write("            0.12      0.08     0.05       0.02\n")
          f.write("            0.01\n")
      
      elif g==23:
	  f.write("      COND 3.679E+06 1.353E+06 5.000E+05 1.110E+05\n")
	  f.write("           6.738E+04 9.118E+03 3.673E+02  4.0\n")
	  f.write("           1.5         1.097    1.045    0.97\n")
	  f.write("           0.85        0.50     0.40     0.35\n")
	  f.write("            0.30        0.25     0.18     0.14\n")
	  f.write("          0.10        0.05\n")
      
      elif g==13:
	  f.write("      COND 1.8315E+05 1.014E+03 1.6745E+01 4.1293\n")
	  f.write("              2.13      1.305      0.79    0.62501\n")
	  f.write("             0.391      0.3145     0.115   5.9E-04\n")

      elif g==10:
	  f.write("      COND 1.8315E+05 1.014E+03 1.6745E+01 4.1293\n")
	  f.write("              2.13       0.79     0.391    0.3145 \n")
	  f.write("              0.115     5.9E-04\n")

      elif g==9:
	  f.write("      COND 1.83E+05    9.61E+02   1.76E+01  3.93\n")
	  f.write("              2.38       1.275     0.825    0.13 \n")      
      
      elif g==6:
	  f.write("      COND 1.8315E+05   1.6745E+01     2.13   0.62501\n")
	  f.write("           0.115\n")
      
      elif g==4:
	  f.write("      COND 1.111E+05 29.0 1.86\n")
      
      elif g==2:
	  f.write("      COND 2.38\n")
      else :
	  print ("This number of groups wasn't expected, go back to the program")
          raise NameError
      f.write("  MICR 16 GRAB HE4 O16 NP27 PU38 PU39 PU40\n")
      f.write("          PU41 PU42 AM41 AM42 AM43 C12 SI28 SI29 SI30 \n")
      f.write("      SAVE\n")
      f.write(";\n\n")
      
      f.write("    IF I 1 = THEN\n")
      f.write("      Out1 := OUT ;\n")
      f.write("      OUT := DELETE: OUT ;\n")
      f.write("    ENDIF ;\n")
      f.write("    IF I 2 = THEN\n")
      f.write("      Out2 := OUT ;\n")
      f.write("      OUT := DELETE: OUT ;\n")
      f.write("    ENDIF ;\n")
      f.write("    IF I 3 = THEN\n")
      f.write("      Out3 := OUT ;\n\n")
      f.write("      OUT := DELETE: OUT ;\n")
      f.write("    ENDIF ;\n")
      f.write("    EVALUATE I := I 1 + ;\n")
      f.write("  ENDIF ;\n")
      f.write("*-------------------------------------------------------\n")
      f.write("*  Change delta t for burnup, final time and power if required\n")
      f.write("*--------------------------------------------------------\n")
      f.write("  IF Timef Timec = THEN\n")
      f.write("    IF Timec 500.0 = THEN\n")
      f.write("      EVALUATE Delt Timec := 100.0 1000.0 ;\n")
      f.write("    ENDIF ;\n")
      f.write("    IF Timec 50.0 = THEN\n")
      f.write("      EVALUATE Delt Timec := 50.0 500.0 ;\n")
      f.write("    ENDIF ;\n")
      f.write("  ENDIF ;\n")
      f.write("  EVALUATE Timei := Timef ;\n")
      f.write("ENDWHILE ;\n\n")

      f.write("* Termination of the script : cleaning and end.\n\n")

  f.write('*---\n')
  f.write('* Mixtures merge for Instant :\n')
  f.write('* Fuel cell 01 merged completely\n')
  f.write('*---\n\n')

  # Homogenized mixture 1 : F11, F21,F31,F41,F51,F61,F71,F81
  for g in gr:

      f.write("*************\n")
      f.write("*"+str(g)+" Groups *\n")
      f.write("*************\n\n")

      f.write("OUT := EDI: FLUX LIBRARY TRACK1 GEOM ::\n")
      f.write("   EDIT 3\n")
      f.write("   MERGE MIX\n")
      f.write("*1 2 3 4 5 6 7 8 9 10\n")
      k=1
      f.write("* F mixtures : fuel pellet\n")
      while k<=NF:
          if 0<k<10:
	      f.write(" "+str(1))
	  else:
	      f.write(" 0")
	      if k==10:
		  f.write("\n")
	  k=k+1
      f.write("\n")
      k=1
      f.write("* F mixtures : helium and graphite surrounding fuel pellet\n")
      while k<=NF:
          if 0<k<10:
	      f.write(" "+str(1))
	  else:
	      f.write(" 0")
	      if k==10:
		  f.write("\n")
	  k=k+1
      f.write("\n")
      k=1
      f.write("* K mixtures\n")
      while k<=NK:
	  if k==1:
	      f.write(" 1")
	      if k==10:
		  f.write("\n")
	  else:
	      f.write(" 0")
	      if k==10:
		  f.write("\n")
	  k=k+1
      f.write("\n")
      k=1
      f.write("* C mixtures\n")
      while k<=NC:
	  if k==1:
	      f.write(" 1")
	      if k==10:
		  f.write("\n")
	  else:
	      f.write(" 0")
	      if k==10:
		  f.write("\n")
	  k=k+1
      f.write("\n")
      k=1
      f.write("* B mixtures\n")
      while k<=NB:
	  if k==1:
	      f.write(" 1")
	      if k==10:
		  f.write("\n")
	  else:
	      f.write(" 0")
	      if k==10:
		  f.write("\n")
	  k=k+1
      f.write("\n")
      k=1
      f.write("* G mixtures\n")
      while k<=NG:
	  if k==1:
	      f.write(" 1")
	      if k==10:
		  f.write("\n")
	  else:
	      f.write(" 0")
	      if k==10:
		  f.write("\n")
	  k=k+1
      f.write("\n")
      k=1
      f.write("* J mixtures\n")
      while k<=NJ:
	  if k==1:
	      f.write(" 1")
	      if k==10:
		  f.write("\n")
	  else:
	      f.write(" 0")
	      if k==10:
		  f.write("\n")
	  k=k+1

      f.write("\n")
  #  Group condensations :
      if g==295:
	f.write("  COND NONE\n")
      
      elif g==26:
          f.write("  COND 7.408E+06 3.679E+06 6.721E+05 1.111E+05\n")
          f.write("       1.931E+04 3.355E+03 1.585E+03 7.485E+02\n")
          f.write("       2.754E+02 1.301E+02 6.144E+01   29.0\n")
          f.write("       13.70      8.32     5.04       2.38\n")
          f.write("        1.29      0.65     0.35       0.20\n")
          f.write("        0.12      0.08     0.05       0.02\n")
          f.write("        0.01\n")
      
      elif g==23:
	  f.write("  COND 3.679E+06 1.353E+06 5.000E+05 1.110E+05\n")
	  f.write("       6.738E+04 9.118E+03 3.673E+02  4.0\n")
	  f.write("       1.5         1.097    1.045    0.97\n")
	  f.write("       0.85        0.50     0.40     0.35\n")
	  f.write("       0.30        0.25     0.18     0.14\n")
	  f.write("       0.10        0.05\n")
      
      elif g==13:
	  f.write("  COND 1.8315E+05 1.014E+03 1.6745E+01 4.1293\n")
	  f.write("          2.13      1.305      0.79    0.62501\n")
	  f.write("         0.391      0.3145     0.115   5.9E-04\n")

      elif g==10:
	  f.write("  COND 1.8315E+05 1.014E+03 1.6745E+01 4.1293\n")
	  f.write("          2.13       0.79     0.391    0.3145 \n")
	  f.write("          0.115     5.9E-04\n")

      elif g==9:
	  f.write("  COND 1.83E+05    9.61E+02   1.76E+01  3.93\n")
	  f.write("          2.38       1.275     0.825    0.13 \n")      
      
      elif g==6:
	  f.write("  COND 1.8315E+05   1.6745E+01     2.13   0.62501\n")
	  f.write("       0.115\n")
      
      elif g==4:
	  f.write("  COND 1.111E+05 29.0 1.86\n")
      
      elif g==2:
	  f.write("  COND 2.38\n")
      else :
	  print ("This number of groups wasn't expected, go back to the program")
          raise NameError
      f.write("  MICR 16 GRAB HE4 O16 NP27 PU38 PU39 PU40\n")
      f.write("          PU41 PU42 AM41 AM42 AM43 C12 SI28 SI29 SI30 \n")
      f.write("  SAVE\n")
      f.write(";\n\n")
      f.write("OutF := OUT ;\n")
      f.write("OUT := DELETE: OUT ;\n\n")

      f.write("TRACK1  := DELETE: TRACK1 ; \n\n")
      f.write("LIBRARY := DELETE: LIBRARY ; \n")
      f.write("BURNUP := DELETE: BURNUP ; \n")

      f.write("END: ;\n")
      f.write('QUIT "LIST" .\n')

  f.close()
  print "End of DragSupCell.py with : "+str(Nbg)+" groups."

# make it run as a script

if __name__ == "__main__":
    import sys
    DragSupCell(int(sys.argv[1]))

#end

