#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Program : compare.py
# Author : Vincent Descotes, 7/07/2010 
# Purpose : creates a file in current directory where 2 vtk files 
#           are substracted in order to do comparisons (errors).
# Input :  File1, File2 : names (end path) of the 2 files to be substracted
#              as File1-File2, so File 2 is the reference. Those variables contain strings. Files must be located in
#              the current directory.
#    Example : /home/descv/VHTR_4/Full_core4/Results_4/SupCell2_26gr/FissionSource-p0.vtk becomes :
#             FissionSource-p0.vtk
# Output : new file Difference.vtk creted in current directory

def compare(File1,File2):
    import numpy
    import math
    import os
    INPTPATH=os.getcwd()
#Opening file Difference.vtk to be written
    f = open(INPTPATH+"/"+'Difference_NormPowers.vtk', 'w')

#Opening file to be read
    r1 = open(INPTPATH+"/"+File1, 'r')
    r2 = open(INPTPATH+"/"+File2, 'r')

#Write the begining (comments) of the vtk file.
    f.write('# vtk DataFile Version 3.0\n')
    f.write('#This file was generated by compare.py to plot : ')
    f.write(File1 + ' - ' + File2 +'\n')

#Read comments lines of Files 1 and 2
    r1.readline()
    r1.readline()
    r2.readline()
    r2.readline()

#Should be at ASCII now.
    s1 = r1.readline()
    s2 = r2.readline()

    if s1[0:5] != 'ASCII':
        print ('Error,' +str(File1)+ 'doesn''t begins with only 2 comments !\n')
        print ('Line in ' + str(File1) + ' :')
        print (str(r1.tell()))
        print s1
        print ('Exit from the program !')
        r1.close()
        r2.close()
        f.close()
        return

    if s2[0:5] != 'ASCII':
        print ('Error, '+str(File2)+' doesn''t begins with only 2 comments !\n')
        print ('Exit from the program !')
        r1.close()
        r2.close()
        f.close()
        return

#Copy the first part of the files (mesh points) in f. They should be exactly the same.
    while s1[0:22] !='POINT_DATA         392':
        if s1 != s2 :
            print ('Error on line :\n'+ s1)
            print ('The two file seems to have different meshes')
            r1.close()
            r2.close()
            f.close()
            return
        f.write(s1)
        s1 = r1.readline()
        s2 = r2.readline()

    if s1 != s2 :
        print ('Error on line :\n'+s2)
        print ('The two file seems to have different meshes')
        r1.close()
        r2.close()
        f.close()
        return

#Write POINT_DATA..., and the 2 next lines until LOOKUP_TABLE default
    while s1[0:20] != 'LOOKUP_TABLE default':
        if s1 != s2 :
            print ('Error on line ')
            print ('The two file seems to have different meshes')
            r1.close()
            r2.close()
            f.close()
            return
        f.write(s1)
        s1 = r1.readline()
        s2 = r2.readline()

#Write Lookup_table line
    f.write(s1)
# Store the current position of the files. We will have to read them twice to find the minimal powers.
    label1 = r1.tell()
    label2 = r2.tell()
#Compute the average power in each file ; store the maximum absolute power in each file.
    Pav1=0.0
    Pav2=0.0
    Pmax1=0.0
    Pmax2=0.0
    N1=0.0
    N2=0.0
    i=1
    while i != 393:
        r1.seek(2,1)
        r2.seek(2,1)         
        s1 = r1.read(13)
        s2 = r2.read(13)
#        print s1
#        print i
# Determination of the number of fuel assemblies (P non equal to 0...)
        if float(s1) > 0.0:
            N1=N1+1
        if float(s2) > 0.0:
            N2=N2+1
        Pav1 = Pav1+float(s1)
        Pav2 = Pav2+float(s2)
#Search for the maximum powers in each file
        if float(s1)>Pmax1:
            Pmax1=float(s1)
        if float(s2)>Pmax2:
            Pmax2=float(s2)
        if numpy.remainder (i,7) == 0: # there are 7 points per line, that is to say per block, for a flatfiss vtk file.
           r1.seek(2,1)
           r2.seek(2,1)
        i=i+1
    print ('Number of fuel nodes in file '+File1+' :')
    print int(N1)
    print ('Number of fuel nodes in file '+File2+' :')
    print int(N2)
    if int(N1) != int(N2):
        print ('N1 != N2 : there must be a problem, meshes maybe different ?')
        return
    Pav1=Pav1/N1
    Pav2=Pav2/N2
    print ('Finished to compute the average and maximal powers in each file.')
# Initialization of Pmin1 and Pmin2 before their calculation
    Pmin1=Pmax1
    Pmin2=Pmax2
# Initialization of Mindiff, Maxdiff, Avdiff, Avdiff2 and RMS before their calculation. Those variables are related to the new vtk file with the differences.
    Mindiff = max(Pmax1/Pav1,Pmax2/Pav2)
    Maxdiff = -max(Pmax1/Pav1,Pmax2/Pav2)
    Avdiff  = 0.0 
    Avdiff2 = 0.0
    RMS = 0.0

    print ('Begin the substraction of the two files')
#Substraction File1 - File2 : the numbers are coded on 13 characters with two blank spaces between each. Return \n every 7 numbers.
#Verify that there are 392 points data. I however cannot code to do the work until the end automatically...
    r1.seek(label1) # go up to label1 (begining of the "lookup table")
    r2.seek(label2) # same goes for File2
    i=1
    j=1
    while i != 393:
        r1.seek(2,1)
        r2.seek(2,1)         
        s1 = r1.read(13)
        s2 = r2.read(13)

# Search the absolute minimum in the fuel :
        if float(s1) < Pmin1 and float(s1) != 0.0:
            Pmin1=float(s1)
        if float(s2) < Pmin2 and float(s2) != 0.0:
            Pmin2=float(s2)

# ATTENTION : we look at the difference with normalized powers to respective average powers, divided by the second file (reference) and multiplied by 100 to have percents.
# If s2 = 0 : no division.
        if float(s2) == 0.0: 
            if float(s1) != 0.0:
                print('WARNING ! WARNING ! Their is a fuel zone in the first file that doesn''t exist in the second, reference file. Results may be completely wrong')
                print('Position : '+str(r1.tell()))
            d = (float(s1)/Pav1 - float(s2)/Pav2)
        else :
            d = (float(s1)/Pav1 - float(s2)/Pav2)/(float(s2)/Pav2)*100
# Compute the minimal difference, the maximal difference, the average absolute difference (norm 1), and the RMS.
            if d < Mindiff:
                Mindiff = d
            if d > Maxdiff:
                Maxdiff = d
            Avdiff  = Avdiff + d
            Avdiff2 = Avdiff2 + abs(d)
            RMS = RMS + (d)**2
# Writing the difference in the Difference.vtk file with the correct format (this was tricky to do !) :
        s=format(d,'.6E')
        part=s.partition('E')
        f.write("  "+s.replace(part[1]+part[2][0],part[1]+part[2][0]+'0'))
        if numpy.remainder (i,7) == 0:
           f.write(" \n")
           r1.seek(2,1)
           r2.seek(2,1)
           print ("Block number : "+str(j))
           print ("difference = "+str(s)+" %\n")
           j=j+1
        i=i+1
    f.write(" ")
# Compute the relative maximum and minimum powers in each file
    Pmax1=Pmax1/Pav1
    Pmin1=Pmin1/Pav1
    Pmax2=Pmax2/Pav2
    Pmin2=Pmin2/Pav2
# Compute the parameters related to the new file. N2 is the number of fuel elements.
    print ("N2 = "+str(int(N2)))
    Avdiff = Avdiff/N2 # normal average
    print ('Avdiff = '+str(Avdiff))
    Avdiff2 = Avdiff2/N2 # norm 1
    print ('Avdiff2 = '+str(Avdiff2))
    RMS = 1.0/N2*RMS - Avdiff**2
    print ('RMS^2 = '+str(RMS))
    RMS = math.sqrt(RMS)
# Printings on screen
    print ('Finished to search for the minimum powers.\n')

    print ('Finished to substract the files, new file created :')
    z=str(f).find("'",12)
    print (str(f)[12:z]+'\n')
    
    print ('Power parameters of file '+File1+' :')
    print ('Average power over the whole core = '+str(Pav1))
    print ('Maximum power in fuel = '+str(Pmax1))
    print ('Minimum power in fuel = '+str(Pmin1)+'\n')

    print ('Power parameters of file '+File2+' :')
    print ('Average power over the whole core = '+str(Pav2))
    print ('Maximum power in fuel = '+str(Pmax2))
    print ('Minimum power in fuel = '+str(Pmin2)+'\n')
    
    print ('***')
    print ('Normal average error            = '+str(Avdiff)+' %')
    print ('Root mean square                = '+str(RMS)+' %')
    print ('***')
    print ('Average of the absolute errors  = '+str(Avdiff2)+' %')
    print ('Maximal error on the power differences = '+str(Maxdiff)+' %')
    print ('Minimal error on the power differences = '+str(Mindiff)+' %')
    f.close()
    r1.close()
    r2.close

# make it run as a script

if __name__ == "__main__":
    import sys
    for arg in sys.argv:
        print arg
    compare(str(sys.argv[1]),str(sys.argv[2]))

#end

