#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# Program : average_Power.py
# Author : Vincent Descotes, 7/07/2010 
# Purpose : create a file in ~/VHTR_4/Full_core4/Results_4/ where 1 vtk file
#           is changed to plot a sort of average powers over each assembly.
# Input :  File1, File2 : names (end path) of the 2 files to be substracted
#              as File2-File1. Those variables contain strings. Files must be located in
#              /home/descv/VHTR_4/Full_core4/Results_4/...
#    Example : /home/descv/VHTR_4/Full_core4/Results_4/SupCell2_26gr/FissionSource-p0.vtk becomes :
#             SupCell2_26gr/FissionSource-p0.vtk
# Output : new file Average_Power.vtk in above directory

def average_Power(File1):
    import numpy
    import os
    INPTPATH=os.getcwd()
#Opening file Average_Power.vtk to be written
    f = open(INPTPATH+"/"+'Average_Power.vtk', 'w')

#Opening file to be read
    r1 = open(INPTPATH+"/"+File1, 'r')

#Write the begining (comments) of the vtk file.
    f.write('# vtk DataFile Version 3.0\n')
    f.write('#This file was generated by average_Power.py to plot : ')
    f.write(File1+'\n')

#Read comments lines of Files 1
    r1.readline()
    r1.readline()

#Should be at ASCII now.
    s1 = r1.readline()

    if s1[0:5] != 'ASCII':
        print ('Error,' +str(File1)+ 'doesn''t begins with only 2 comments !\n')
        print ('Line in ' + str(File1) + ' :')
        print (str(r1.tell()))
        print s1
        print ('Exit from the program !')
        r1.close()
        f.close()
        return

#Copy the first part of the files (mesh points) in f. They should be exactly the same.
    while s1[0:22] !='POINT_DATA       77672':
        f.write(s1)
        s1 = r1.readline()

#Write POINT_DATA..., and the 2 next lines until LOOKUP_TABLE default
    while s1[0:20] != 'LOOKUP_TABLE default':
        f.write(s1)
        s1 = r1.readline()

#Write Lookup_table line in the new file. Ready to write the values.
    f.write(s1)

    label1 = r1.tell()
#Compute the average power in old file ; store the maximum absolute power in old file.
    Pav1=0.0
    Pmax1=0.0
    N1=0
    i=1
    while i != 77673:
        r1.seek(2,1)        
        s1 = r1.read(13)
        if float(s1) > 0.0:
            N1=N1+1
        Pav1 = Pav1+float(s1)
#Search for the maximum powers in each file
        if float(s1)>Pmax1:
            Pmax1=float(s1)
        if numpy.remainder (i,1387) == 0:
           r1.seek(2,1)
        i=i+1
    print ('Number of fuel nodes in file '+File1+' :')
    print N1

    Pav1=Pav1/N1

    print ('Finished to compute the global average power : '+str(Pav1)+"\n")

    Pmin1=Pmax1
    print ('Begin to compute the average powers in each block')
#Substraction File1 - File2 : the numbers are coded on 13 characters with to blank spaces between each. Return \n every 7 numbers.
#Verify that there are 392 points data. I however cannot say to do the work until the end...
    r1.seek(label1) # go up to label1 (begining of the "lookup table")
    i=1
    j=1
    P=[]
    d=0.0
    while i != 77673:
        r1.seek(2,1)
        s1 = r1.read(13)

# Search the absolute minimum in the fuel :
        if float(s1) < Pmin1 and float(s1) != 0.0:
            Pmin1=float(s1)

# ATTENTION : compute the average powers : P_block = (sum(i=1..1387) Pi/Pav1)/1387. 1387 because there are 1387 points in each block.
#             Powers will be normalized. Store the result in an array d (56 elements)

        d=d+float(s1)
        if numpy.remainder (i,1387) == 0:
            d=d/(Pav1*1387.0)
            P.append(d)
            r1.seek(2,1)
            print ("Average power in block number "+str(j)+" :")
            print ("   "+str(d)+"\n")
            d=0.0
            j=j+1
        i=i+1
    print ("Total number of blocks found : "+str(j-1)+"\n")
    print ('Finished to search for the minimum powers.\n')

#----------------------------------------------------------
# Write the new file with the average powers in each block:
#----------------------------------------------------------

    i=1
    j=1
    k=1
    while i != 77673:
        s=format(P[k-1],'.6E')
        part=s.partition('E')
        f.write("  "+s.replace(part[1]+part[2][0],part[1]+part[2][0]+'0'))
#        if numpy.remainder(j,10) == 0:
#            f.write("\n")
        if numpy.remainder (i,1387) == 0:
           f.write(" \n")
           j=0
           k=k+1
        i=i+1
        j=j+1
    f.write(" ")
# Compute the relative maximum and minimum powers in the file
    Pmax1=Pmax1/Pav1
    Pmin1=Pmin1/Pav1
# Printings on screen


    print ('Finished to write the file, new file created :')
    z=str(f).find("'",12)
    print (str(f)[12:z]+'\n')
    
    print ('Power parameters of file '+File1+' :')
    print ('Old average power over the whole core = '+str(Pav1))
    print ('New Maximum power in fuel = '+str(Pmax1))
    print ('New Minimum power in fuel = '+str(Pmin1)+'\n')

    f.close()
    r1.close()

# make it run as a script

if __name__ == "__main__":
    import sys
    for arg in sys.argv:
        print arg
    average_Power(str(sys.argv[1]))

#end

