#!/bin/bash
# Main script to perform the whole INSTANT calculation scheme with the P1 diffusion approximation.
# Call : Core_calc_P1.sh -g<number of groups> -meth<0/1> -scat<0/1>
#        meth 0 : mimic diffusion; meth 1 : normal Pn.
#        scat 0 : isotropic scattering; scat 1 : linear anisotropic scattering.
# Attention, you must have pick up a node...
# (don't use the brackets <> in the call, and no space between g and the integer). Only 1 number of group allowed at a time.
echo "****************************************************"
echo "INSTANT CALCULATION SCHEME P1 : SB_moc, HOM26 path :"
echo "****************************************************"
echo "!!!"
echo "!!! Did you think to pick up a node before starting ???"
echo "!!!"
echo "Current directory for cross-sections (verify !)"
echo "        " `pwd`
echo "  "

DIR=`pwd`
DIR2=/home/descv/VHTR_SB_moc/HOM26
DIRXS=/home/descv/VHTR_SB_moc/HOM26/Full_core_P1/xs
NbG=""

if [ $DIR != $DIR2 ]; then
    echo "You must start from directory VHTR_SB_moc/HOM26"
    echo "Your are now in directory :" $DIR
    exit 1
fi

#Recover the number of groups wanted in the variable NbG, M (for meth) and S (for scat) :
for param in $*
do
    case $param in
        -g*) NbG="`echo $1 | cut -c 3-`" ;;
        -meth*) M="`echo $1 | cut -c 6-`" ;;
        -scat*) S="`echo $1 | cut -c 6-`" ;;  
    esac
    shift
done
echo "Number of groups taken : "$NbG
echo ""
echo "Method : "$M
echo "Scattering order : "$S 
echo ""

if [ $NbG = 295 ]; then
    echo "You tried 295 groups whereas the calculations have been done starting with 26 groups"
    echo "Therefore I will exit the code."
    exit 1
fi

if [ $NbG = 23 ]; then
    echo "You tried 23 groups whereas reflector XS doesn't exist in this structure when we start with 26 groups"
    echo "Therefore I will exit the code."
    exit 1
fi

if [ $NbG = 13 ]; then
    echo "You tried 13 groups whereas reflector XS doesn't exist in this structure when we start with 26 groups"
    echo "Therefore I will exit the code."
    exit 1
fi
sleep 2s

# begin the script by copying the cross-sections :
echo "********************************************"
echo "Call the copying script for cross-sections :"
echo "********************************************"
echo ""
if [ $M = 0 ]; then
    echo "You are trying to mimic diffusion, but we have not been able to produce refelctor cross-sections with B10 starting with 26 groups."
    echo "Therefore, it is not possible to fullfill this calculation and I will close the code."
    exit 1
else
    ./copy_P1.sh -g$NbG
fi

sleep 2s

#Go into ./Full_core_P1 to pursue the task and create the DRAG2INSm.inp file
echo "*******************************"
echo "Go to Full_core_P1 directory  :"
echo "*******************************"
echo ""
cd ./Full_core_P1
pwd
echo ""

echo "**************************************"
echo "Create the input for DRAG2Insm3.f90  :"
echo "**************************************"
echo ""
./WriteDrag2InsInp.py $NbG $M $S
echo ""
sleep 2s

#Build the INSTANT inp.xml file.
echo "********************************************"
echo "Call the transfer script to build inp.xml  :"
echo "********************************************"
./transfer.sh
sleep 2s

#Move the inp.xml file into ./Instant_calc and go inside
echo "********************************************"
echo "Move new inp.xml into the Instant directory :"
echo "********************************************"
echo ""
mv -v inp.xml ./Instant_calc
cd ./Instant_calc
echo ""

#Clean this directory for the calculation
echo "************************************************"
echo "Clean the Instant directory before calculation :"
echo "************************************************"
rm *.vtk *.ps all_parameters.xml INSTANT.outp trash-*
echo "List all files inside the directory after cleaning :"
echo "      "`pwd`
echo ""
ls

echo ""
sleep 2s

#do the INSTANT calculation
echo "******************************"
echo "Do the INSTANT calculation :"
echo "******************************"
echo ""
echo "Number of groups : "$NbG
./instant inp.xml

echo "Time to notice the k-effective !"
echo ""
sleep 2s

#Move the interesting files : for the flux, the 3 first files and 3 last files. Attention with 4 and 2 groups, take all of them.
echo "*******************************************************"
echo "Move the interesting files into Results_P1/... :" $NbG
echo "*******************************************************"
RES=Results_P1/SB_$NbG"gr"

mv -v inp.xml ../$RES
mv -v FissionSource-p0.vtk ../$RES
mv -v Initial-Mesh-p0.vtk ../$RES
mv -v Initial-Mesh-p0.ps ../$RES
mv -v INSTANT.outp ../$RES

if [ "$NbG" = "2" ] || [ "$NbG" = "4" ]; then
   mv -v flux*-even1-p0.vtk ../$RES
else
   mv -v flux1-even1-p0.vtk ../$RES
   mv -v flux2-even1-p0.vtk ../$RES
   mv -v flux3-even1-p0.vtk ../$RES

   mv -v flux$NbG"-even1-p0.vtk" ../$RES
   NbG1=$[$NbG-1]
   NbG2=$[$NbG-2]
   mv -v flux$NbG1"-even1-p0.vtk" ../$RES
   mv -v flux$NbG2"-even1-p0.vtk" ../$RES
fi

#Go inside the result directory and check what has been transferred.
echo "*******************************************************"
echo "List the files transfered into Results_P1/... + keff :" $NbG
echo "*******************************************************"
echo ""
cd ../$RES

ls -l | cut -c 33-
echo ""
echo "Final INSTANT K-effective :"
grep 'k-eff=' INSTANT.outp | tail -n1
echo ""
echo "*******************************************************"
echo " End of the script Core_calc_P1.sh !"
echo "*******************************************************"

