!  DRAG2INSm.f90 
!
!  FUNCTIONS:
!	DRAGONXS      - READ CROSS SECTIONS FROM DRAGON OUTPUT.
!
!
!****************************************************************************
!
!  PROGRAM: DRAG2INSm
!
!  READ CROSS SECTIONS FROM DRAGON OUTPUT.
!
!****************************************************************************
!  AUTHOR: JAVIER ORTENSI - Idaho National Laboratory
!  DATE:   7/23/2010
!****************************************************************************
!
!  INPUTS:
!		   DRAGON.inp - contains the material number and cross section file 
!						(does not have to be in order)
! 
program DRAGONXS

implicit none

	! Variables
character dums*52,src*25,s14*14,s20*20,s8*8,opt*5,s4*4,s40*40,s5*5
integer ::i,j,kk,iblk,nblk,dumi,gr,n,o,stat,nfiles,nchi=0,niso,ngr,meth,l,pl
real :: dumr, chibar(300)=0d0,chisum(300)=0d0  
logical :: go

type micParatype
	 character (len=6) :: ISO=""
     real:: N=0d0 
     real:: NTOTO(300)=0d0 
	 real:: STRD(300)=0d0
     real:: TRANC(300)=0d0
	 real:: NUSIGF(300)=0d0
	 real:: NFTOT(300)=0d0  
	 real:: CHI(300)=0d0
     real:: SCAT(300,300,2)=0d0 
end type micParatype

! derived type for macroscopic diffusion parameters
type DiffParatype
	 character (len=10) :: LOC=""
     logical :: fiss
     real:: SIGT(300)=0d0
	 real:: SIGTR(300)=0d0
     real:: TRANC(300)=0d0
	 real:: SIGA(300)=0d0 
	 real:: DIFCO(300)=0d0
	 real:: nuSIGF(300)=0d0
	 real:: SIGF(300)=0d0  
	 real:: CHIF(300)=0d0
     real:: SCAT(300,300,2)=0d0  
	 real:: SIGR(300)=0d0
end type DiffParatype

type matmapping
     integer :: num(600)=0
	 character (len=20) :: xsfile(600)=""
     character (len=5) :: opt(600)=""
end type matmapping 

type scatprofiles
   integer :: start=0,end=0
end type scatprofiles

type (matmapping):: matmap 
type (micParatype):: micxs(30)
type (DiffParatype),allocatable, dimension(:) :: diff

open(unit=97,file='DRAG2INSm.inp', status='old')

stat=0
nfiles=0
!
!!!!!!!!!!!!!!!!!!!!! PROCESS INPUT FILE  !!!!!!!!!!!!!!!!!!
!
read(97,'(A4,I4)') s4,ngr
if (s4/='ngr ') then
	write(*,*) 'ngr card must be 2nd in input file'
	STOP
end if

!
!meth  (0/1) (mimic diff in INSTANT / P1 data in INSTANT) & (0,1) Legendre order
!

read(97,'(A4,1x,I1,1x,I1)') s4,meth, pl
if (s4/='meth') then
	write(*,*) 'mth card must be 3rd in input file'
	STOP
end if
! add one to Legendre order for array procesing
pl=pl+1

! check files header
read(97,'(A5)') s5
if (s5/='files') then
	write(*,*) 'files card must be 4th in input file'
	STOP
end if
! start reading files
do while (stat == 0)
	read(97,*, iostat=stat) i, s20, s5
	
    if (stat==0) then
		nfiles=nfiles+1
        matmap%num(nfiles)=i
		matmap%xsfile(nfiles)=s20
        matmap%opt(nfiles)=s5
	endif
enddo

!!!!!!!!!!!!!!!!!!  END OF INPUT PROCESSING  !!!!!!!!!!!!!!!!

nblk=i   
allocate( diff(i))

block_loop1: do kk=1,nfiles
  iblk=matmap%num(kk)
  opt=matmap%opt(kk)
  ! open main or background ISOTXS file
  src=trim(matmap%xsfile(kk))
  
  if (opt=="micro") then
				s20="./xs/"//trim(src)//".edi"
				open(unit=98,file=s20,form='FORMATTED', status='old')
				s20="./xs/"//trim(src)//".N"
				open(unit=99,file=s20,form='FORMATTED', status='old')
				!  print status
				write(*,*) 'START Processing file ', s20

			    call getmic
	            call buildmac
  elseif (opt=="macro") then
		s20="./xs/"//trim(src)
		open(unit=98,file=s20,form='FORMATTED', status='old')
		write(*,*) 'START Processing file ', s20
		call getmac
  else
	write(*,*) 'Not an option'
	STOP
 endif 

! clean small scattering x-sec
 do l=1,pl
  do n = 1, ngr
    do i = 1, ngr
      dumr= abs(diff(iblk)%SCAT(i,n,l) )
       if ( dumr  < 1E-10 )  diff(iblk)%SCAT(i,n,l)=0. 
	enddo
  enddo	
 enddo
 close(98)
  write(*,*) 'END Processing file ', s20
enddo block_loop1

! WRITE FILE FOR INSTANT
call writeins

close(96)
close(97)
CONTAINS
!**********************************************************************************************
!**********************************************************************************************
!**********************************************************************************************

  subroutine getmic
  implicit none
  integer ijj(ngr),njj(ngr),nb,nbi,k,i,j,n,l
  real, allocatable, dimension(:) :: scatblock
  logical p1scat

   ! clear microscopic
   do i=1,30
	     micxs(i)%ISO=""     ;  micxs(i)%N=0d0 
	     micxs(i)%NTOTO=0d0  ;  micxs(i)%STRD=0d0
	     micxs(i)%NUSIGF=0d0  ; micxs(i)%NFTOT=0d0  
	     micxs(i)%CHI=0d0    ;  micxs(i)%SCAT=0d0
		 micxs(i)%TRANC=0d0     
   enddo
    ! find ISOTOPESDENS in .N file unit 99

    read(99,'(/,I2)') niso
    read(99,*) dums
    
    if( trim(dums) /= "ISOTOPESDENS") then
        write(*,*) "No ISOTOPESDENS marker.  Program will stop."
        STOP
    end if
    
    do i= 1, niso
        read(99,'(A4,/,E13.6)') micxs(i)%ISO, micxs(i)%N
    enddo
    close(99)

! find chi in macro section of edi file unit 98
	      do n=1, ngr   
		    ! find CHI
			dums=''
		    do while ( trim(dums) /=   "CHI" )
		       read(98,'(A52)',end=300) dums
		    enddo
		    ! read chi spectrum
	        read(98,*) diff(iblk)%CHIF(n)
			write(*,*) 'Read Spectrum group =',n
          enddo
!  for materials that have no fuel
300 Continue
rewind(98)

! find the cross section for each isotope in .edi file unit 98
   do l = 1, niso
	  dums=''
      do while ( trim(dums) /=   "AWR" )
		read(98,'(A52)') dums
      enddo
      backspace(98) ; backspace(98) ;backspace(98) 
      read(98,*) dums
	  ! find the record that matches isotope information
	  loop_1:do k =1, niso
		if ( trim(dums) == trim(micxs(k)%ISO) ) then
			i = k
			exit loop_1
		end if
		
	  end do loop_1

	  write(*,*) '******** Reading microscopic data for ', micxs(i)%ISO, '**********'
      dums=''
      do while ( trim(dums) /=   "NTOT0" )
		read(98,'(A52)') dums
      enddo
	  ! read total cross sections
	    read(98,*) (micxs(i)%NTOTO(j),j=1,ngr)
		write(*,*) 'Read NTOTO'
        read(98,*)
		read(98,*) dums
	  if(trim(dums) == "NUSIGF")then 
 
 		write(*,*) 'isotope IS fissile or fissionable'
          ! read nusigmaf cross sections
	      read(98,*) (micxs(i)%NUSIGF(j),j=1,ngr) 
          write(*,*) 'Read NUSIGF'
		  read(98,*) ;   read(98,*)  dums
		  ! read sigmaf cross sections
	      if ( trim(dums) == "NFTOT" ) then
		  
		   read(98,*) (micxs(i)%NFTOT(j),j=1,ngr) 
		   write(*,*) 'Read NFTOT'
		  end if
		   
          ! find CHI
!		  do while ( trim(dums) /=   "CHI" )
!		      read(98,'(A52)') dums
!		  enddo
		  ! read chi spectrum
!	      read(98,*) (micxs(i)%CHI(j),j=1,ngr)

		else

 		write(*,*) 'isotope NOT fissile or fissionable'

      endif

	  ! find the transport corrections
       if (meth== 0) then  
           dums=''
          do while ( trim(dums) /=   "TRANC" )
		     read(98,'(A52)') dums
          enddo
	      ! read transport cross sections
	      read(98,*) (micxs(i)%TRANC(j),j=1,ngr)
		  write(*,*) 'Read TRANC'

	  ! find the transport cross section if needed  
!           dums=''
!          do while ( trim(dums) /=   "STRD" )
!		     read(98,'(A52)') dums
!          enddo
!      ! read transport cross sections
!	      read(98,*) (micxs(i)%STRD(j),j=1,ngr)
!		  write(*,*) 'Read STRD'
       end if
njj=0.
ijj=0.
! **********************  SCATTERING BLOCK *************************

     do while ( dums /=   "NJJS00" )
		read(98,'(A52)') dums
      enddo
		! read njj flags
	    read(98,*) (njj(j),j=1,ngr)
		write(*,*) 'Read NJJ00'
     do while ( dums /=   "IJJS00" )
		read(98,'(A52)') dums
      enddo
		! read ijj flags
	    read(98,*) (ijj(j),j=1,ngr)
		write(*,*) 'Read IJJ00'

     do while ( dums /=   "SCAT00" )
		read(98,'(A52)') dums
      enddo
	  ! find block size
	  backspace(98) ; backspace(98)

	  read(98,*) s4,dumI,dumI,dumI,nb
	  read(98,*) s4
      allocate(scatblock(nb))
	  ! read scattering block
	  read(98,*) ( scatblock(j),j=1,nb )
	  write(*,*) 'Read SCAT00'


	  
	  ! read scattering cross sections
	   nbi=0
	   do k = 1,ngr
	      do j=ijj(k),ijj(k)-njj(k)+1,-1
		    nbi=nbi+1
	        micxs(i)%SCAT(j,k,1)=scatblock(nbi)
	      enddo
	   enddo  
	   write(*,*) 'Transferred SCAT00'
       deallocate(scatblock)
	
njj=0.
ijj=0.

! **********************  P1 SCATTERING BLOCK *************************
		read(98,*)   
		read(98,'(A52)') dums
		
	if ( trim(dums) ==   "NJJS01" ) then
			! read njj flags
			read(98,*) (njj(j),j=1,ngr)
			write(*,*) 'Read NJJ01'

		do while ( dums /=   "IJJS01" )
			read(98,'(A52)') dums
		enddo
			! read ijj flags
			read(98,*) (ijj(j),j=1,ngr)
			write(*,*) 'Read IJJ00'

		do while ( dums /=   "SCAT01" )
			read(98,'(A52)') dums
		enddo
		! find block size
		 backspace(98) ; backspace(98)

		read(98,*) s4,dumI,dumI,dumI,nb
		read(98,*) s4
		allocate(scatblock(nb))
		! read scattering block
		 read(98,*) ( scatblock(j),j=1,nb )
		write(*,*) 'Read SCAT01'


	  
		! read scattering cross sections
		 nbi=0
	   do k = 1,ngr
	      do j=ijj(k),ijj(k)-njj(k)+1,-1
		    nbi=nbi+1
	        micxs(i)%SCAT(j,k,2)=scatblock(nbi)
	      enddo
	   enddo  
       write(*,*) 'Transferred SCAT01'
       deallocate(scatblock)	
	
	 endif
	  
    enddo

  return
  end subroutine getmic
!**********************************************************************************************
  subroutine buildmac
  implicit none
  integer k,n,i,l
!  builds macroscopic properties from microscopic x-sections

	 diff(iblk)%fiss=.false.
   ! loop through all isotopes
   do i = 1, niso 
	 ! loop through all energies
     do n=1,ngr
		diff(iblk)%SIGT(n)=diff(iblk)%SIGT(n)+micxs(i)%N*micxs(i)%NTOTO(n)
        !diff(iblk)%SIGTR(n)=diff(iblk)%SIGTR(n)+micxs(i)%N*micxs(i)%STRD(n)
		diff(iblk)%TRANC(n)=diff(iblk)%TRANC(n)+micxs(i)%N*micxs(i)%TRANC(n)
		diff(iblk)%nuSIGF(n)=diff(iblk)%nuSIGF(n)+micxs(i)%N*micxs(i)%NUSIGF(n)
		diff(iblk)%SIGF(n)=diff(iblk)%SIGF(n)+micxs(i)%N*micxs(i)%NFTOT(n)
		do k=1,ngr
		  do l =1,pl
		   diff(iblk)%SCAT(n,k,l)=diff(iblk)%SCAT(n,k,l)+micxs(i)%N*micxs(i)%SCAT(n,k,l)
		  enddo
		enddo

	  enddo
   enddo
	 ! calculate Diff coef, removal xsec
     ! clear traces of fission
	 do n=1,ngr
       if (meth== 0) then
		diff(iblk)%SIGR(n)=diff(iblk)%SIGT(n)-diff(iblk)%SCAT(n,n,1)
        diff(iblk)%DIFCO(n)=1.0/3./(diff(iblk)%SIGR(n)+diff(iblk)%TRANC(n))
       end if
       
		if ( diff(iblk)%nuSIGF(n)< 1E-15) then
            diff(iblk)%nuSIGF(n)=0.
			diff(iblk)%SIGF(n)=0.
			diff(iblk)%CHIF(n)=0.
		else
		  diff(iblk)%fiss=.true.
		endif	
       
     enddo

  return
  end subroutine buildmac 
!**********************************************************************************************
  subroutine getmac
  integer :: i,k,g,nbi,njj,ijj
  real,allocatable,dimension(:):: scatblock
  character:: s80*80,s6*6
 ! real:: dumR
	!  read number of groups in file data
  	s20=''
	do while ( trim(s20) /=   "STATE-VECTOR" )
	    read(98,'(A20)') s20
	enddo
	read(98,*) dumI, dumI 
    ! check group structure
	if (ngr /= dumI) then
		write(*,*) 'Number of groups in XS-file does not match main input'
		STOP
	endif
	!   search for group locator
  	s20=''
	do while ( trim(s20) /=   "GROUP" )
	    read(98,'(A20)') s20
	enddo	
	! start group loop
    group_loop: do g=1,ngr	
	    !   search for group index
		i=0
		do while (i/=g)
			read(98,'(A80)') S80
			Read( s80(75:80), '(i8)' )  i
		enddo

	write(*,*) 'checked group number=',i

	   s6=''
	   do while ( trim(s6) /=   "NFTOT" )
	    	read(98,'(A6)') s6
		enddo
	  ! if (fissi(iblk)==1) then
 			! find fission x-sect
			read(98,*) diff(iblk)%SIGF(g)
	!	end if
	write(*,*) 'found fission cross section'

	    !
		! find Total cross section
		!
		s6=''
		do while ( trim(s6) /=   "NTOT0" )
			read(98,'(A6)') s6
		enddo	
		read(98,*) diff(iblk)%SIGT(g)
		write(*,*) 'found total cross section'
	    !
		! find absorption cross section
		!
		s6=''
		do while ( trim(s6) /=   "ABS" )
			read(98,'(A6)') s6
		enddo	
		read(98,*) diff(iblk)%SIGA(g)
		write(*,*) 'found absorption cross section'
		!
		! fissile entries / nusigf and chi
	    !
		read(98,'(////A6)')s6
		if (s6 == "NUSIGF") then
			diff(iblk)%fiss=.true.	
			read(98,*) diff(iblk)%NUSIGF(g)
			write(*,*) 'found nufission cross section'
			read(98,'(/A6)')s6
			if (trim(s6) =="CHI") then
			   read(98,*) diff(iblk)%CHIF(g)
			   	write(*,*) 'found CHI'
			end if 	
		end if
		! find diffusion coeff
		!s6=''
		do while ( trim(s6) /=   "DIFF" )
			read(98,'(A6)') s6
		enddo	
		read(98,*) diff(iblk)%DIFCO(g)
		write(*,*) 'found diffusion coefficient'

        
		!
		! read volume averaged flux
		!
!		s10=''
!		do while ( trim(s10) /=   "FLUX-INTG" )
!			read(98,'(A10)') s10
!		enddo	
!		read(98,*) flux(iblk,g)
!		write(*,*) 'found average flux'
		!
		! read P0 scattering cross sections
		!
		s6=''
		do while ( trim(s6) /=   "SCAT00" )
			read(98,'(A6)') s6
		enddo	
		! back two lines and read block size
		backspace(98) ; backspace(98)
		read(98,*)s6,dumI,dumI,dumI,nbi
 		allocate(scatblock(nbi))
		read(98,*)
		! read scattering block
		read(98,*) ( scatblock(j),j=1,nbi )
		write(*,*) 'found scattering cross sections'
	    ! read the matrix profile
		read(98,'(//,6x,i4)') njj
        read(98,'(//,6x,i4)') ijj
        k=0
		do j=ijj,ijj-njj+1,-1
		    k=k+1
	        diff(iblk)%SCAT(j,g,1)=scatblock(k)
        enddo

		!
		! read P1 scattering cross sections
		!
		s6=''
		do while ( trim(s6) /=   "SCAT01" )
			read(98,'(A6)') s6
		enddo	
		! back two lines and read block size
		backspace(98) ; backspace(98)
		read(98,*)s6,dumI,dumI,dumI,nbi
		read(98,*)
		! read scattering block
		read(98,*) ( scatblock(j),j=1,nbi )
		write(*,*) 'found scattering cross sections'
	    ! read the matrix profile
		read(98,'(//,6x,i4)') njj
        read(98,'(//,6x,i4)') ijj
        k=0
		do j=ijj,ijj-njj+1,-1
		    k=k+1
	        diff(iblk)%SCAT(j,g,2)=scatblock(k)
        enddo


	   deallocate(scatblock)  


		! find end marker
	   s6=''
	   do while ( trim(s6) /=   "IPOS01" )
	    	read(98,'(A6)') s6
		enddo

        ! calculate transport and removal cross sections
        
        diff(iblk)%SIGTR(g)=1.0/3./diff(iblk)%DIFCO(g)
        diff(iblk)%SIGR(g)=diff(iblk)%SIGT(g)-diff(iblk)%SCAT(g,g,1)



	enddo group_loop     
    
    return
  end subroutine getmac
!**********************************************************************************************
  subroutine writeins
	integer:: i,j,k,l,jlow,jhigh
	integer:: f1(nblk,ngr,pl), f2(nblk,ngr,pl)
	logical nostart,noend
	type (scatprofiles)::profile(nblk,ngr,pl)
!    real scat(iblk,ngr,ngr,pl)

!cccccccccccccccccccccccccccccccccccccc
!c    write INSTANT format
!cccccccccccccccccccccccccccccccccccccc


! create scattering profile
do iblk=1, nblk
     DO n = 1, ngr
		DO l = 1, pl
			f1(iblk,n,l) = 1
			DO o = 1, ngr
				IF (diff(iblk)%SCAT(o,n,l)/=0.) EXIT
				f1(iblk,n,l) = f1(iblk,n,l) + 1
			ENDDO
			f2(iblk,n,l) = ngr
			DO o = ngr, 1, -1
				IF (diff(iblk)%SCAT(o,n,l)/=0.) EXIT
				f2(iblk,n,l) = f2(iblk,n,l) - 1
			ENDDO
		ENDDO
	ENDDO
enddo

	if (meth==0) then
		! modifications to obtain consistent results between Diffusion Theory and P1 Transport in INSTANT
		!  sigt=1/3/D=sigtr
		!  sigs_g->g = 1/3/D-sigr
		!  New approach uses TRANC values instead of SIGTR

		Do iblk=1,nblk
			Do i =1, ngr
				!diff(iblk)%SIGT(i)=diff(iblk)%SIGTR(i)
				!diff(iblk)%SCAT(i,i,1)=diff(iblk)%SIGT(i)-diff(iblk)%SIGR(i)
				diff(iblk)%SIGT(i)=diff(iblk)%SIGT(i)-diff(iblk)%TRANC(i)
				diff(iblk)%SCAT(i,i,1)=diff(iblk)%SCAT(i,i,1)-diff(iblk)%TRANC(i)				
				diff(nblk)%SCAT(i,i,2)=0.
								
			enddo
		enddo
		! set P1 scat = 0.
		pl=1
    endif


!ccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
!c   Write the input.xml file for INSTANT
!ccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

	open (10,file='inp.xml',status='replace')

	!write the beginning of the input file (always the same)
	write(10,'("<INSTANT_INPUTS>")')
	write(10,'("  <Control_parameters>")')
	write(10,'("    <title>295-group full core problem with hexagonal geometry</title>")')
	write(10,'("    <calcul_typ>1</calcul_typ>")')
	write(10,'("    <ndim>2</ndim>")')
	write(10,'("  </Control_parameters>")')

	write(10,'("  <Output_controls>")')
	write(10,'("    <vtkgen>1</vtkgen>")')
	write(10,'("    <dbggeo>t</dbggeo>")')
	write(10,'("    <dbgmat>t</dbgmat>")')
	write(10,'("    <vtkflatfis>t</vtkflatfis>")')
	write(10,'("  </Output_controls>")')

	write(10,'("  <Mesh>")')
	write(10,'("    <multimesh>1</multimesh>")')
	write(10,'("    <pn>1</pn>")')
	write(10,'("    <pint>6</pint>")')
	write(10,'("    <psurf>2</psurf>")')
	write(10,'("    <psour>5</psour>")')
	write(10,'("  </Mesh>")')

	write(10,'("  <IterativeSolver>")')
	write(10,'("    <fiss_src>t</fiss_src>")')
	write(10,'("    <oacc_typ>1</oacc_typ>")')
	write(10,'("    <iacc_typ>0</iacc_typ>")')
	write(10,'("    <epskeff>1.0E-07</epskeff>")')
	write(10,'("    <epsflux>1.0E-05</epsflux>")')
	write(10,'("    <maxouter>500</maxouter>")')
	write(10,'("    <keff0>1.23</keff0>")')
	write(10,'("    <echo>0</echo>")')
	write(10,'("    <maxinner>6</maxinner>")')
	write(10,'("    <PNinner>0</PNinner>")')
	write(10,'("    <omegaon>t</omegaon>")')
	write(10,'("    <maxthml>20</maxthml>")')
	write(10,'("  </IterativeSolver>")')

	write(10,'("  <Geometry type=""hex"">")')
	write(10,'("    <N>21</N>")')
	write(10,'("    <A>20.78461</A>")')
	write(10,'("    <BC>0</BC>")')
	write(10,'("    <triangulated>f</triangulated>")')
	write(10,'("    <comment>Mixture indices")')
	write(10,'("1 : center, reflector cell")')
	write(10,'("2 : ring 1, reflector")')
	write(10,'("3 : ring 2, reflector, boundary with fuel")')
	write(10,'(" ")')
	write(10,'("4 : ring 3, special 4 rows : 1st fuel cell")')
	write(10,'(" ")')
	write(10,'("5 : ring 3, 1st fuel ring (normal)")')
	write(10,'("6 : ring 4, 2nd fuel ring (normal)")')
	write(10,'("7 : ring 5, 3rd fuel ring (normal)")')
	write(10,'("8 : ring 6, 4th fuel ring (normal)")')
	write(10,'("9 : ring 7, 5th fuel ring (normal)")')
	write(10,'(" ")')
	write(10,'("10: ring 6, special 4 rows : 4th cell")')
	write(10,'("11: ring 6, special 5 rows : 5th cell")')
	write(10,'(" ")')
	write(10,'("10: ring 6, special 4 rows : 4th cell")')
	write(10,'("11: ring 6, special 5 rows : 5th cell")')
	write(10,'(" ")')
	write(10,'("12: ring 8, outter reflector, boundary with fuel")')
	write(10,'("13: ring 9, outter reflector, reflector")')
	write(10,'("14: ring 10, outter reflector, boundary with vessel.")')
	write(10,'("    </comment>")')
	write(10,'("    <Symmetry>one-sixth</Symmetry>")')
	write(10,'("    <MaterialID>")')
	write(10,'("                      14")')
	write(10,'("                    13  14")')
	write(10,'("                  12  13  14")')
	write(10,'("                09  12  13  14")')
	write(10,'("              08  11  12  13  14")')
	write(10,'("            07  08  11  12  13  14")')
	write(10,'("          06  07  08  11  12  13  14")')
	write(10,'("        05  06  07  08  11  12  13  14")')
	write(10,'("      03  05  06  07  08  09  12  13  14")')
	write(10,'("01  02  03  04  06  08  10  12  13  14  14")')
	write(10,'(" ")')
	write(10,'("    </MaterialID>")')
	write(10,'("    <SubDomainID>")')
	write(10,'("                      14")')
	write(10,'("                    13  14")')
	write(10,'("                  12  13  14")')
	write(10,'("                09  12  13  14")')
	write(10,'("              08  11  12  13  14")')
	write(10,'("            07  08  11  12  13  14")')
	write(10,'("          06  07  08  11  12  13  14")')
	write(10,'("        05  06  07  08  11  12  13  14")')
	write(10,'("      03  05  06  07  08  09  12  13  14")')
	write(10,'("01  02  03  04  06  08  10  12  13  14  14")')
	write(10,'(" ")')
	write(10,'("    </SubDomainID>")')
	write(10,'("  </Geometry>")')

	!ccccccccccccccccccccccccccc
	!c write the material part c
	!ccccccccccccccccccccccccccc
	write(10,'("<Materials>")') 
	write(10,101) ngr


do iblk=1,nblk
	if (diff(iblk)%fiss) then 
	   write(10,102)	matmap%num(iblk), pl-1
	else
	   write(10,103)  matmap%num(iblk),pl-1
	endif
	   ! write total cross section
	write(10,'("        <TotalXS>")')
	write(10,'((10x,5es13.5))') (diff(iblk)%SIGT(j),j=1,ngr)
	write(10,'("        </TotalXS>")')

	if (diff(iblk)%fiss) then 
		! write NUSIGF
		write(10,'("        <NuFissionXS>")')
		write(10,'((10x,5es13.5))') (diff(iblk)%NUSIGF(j),j=1,ngr)
		write(10,'("        </NuFissionXS>")')
		! write CHI
		write(10,'("        <ChiXS>")')
		write(10,'((10x,5es13.5))') (diff(iblk)%CHIF(j),j=1,ngr)
		write(10,'("        </ChiXS>")')
	endif

    ! write scattering matrix profile
    write(10,'("        <Profile>")')
	
	  do n=1,ngr
	     write(10,'(10x,200I4 )') (f1(iblk,n,l), f2(iblk,n,l), l = 1, pl)
	  enddo

	write(10,'("        </Profile>")')

	! write scattering matrix
	write(10,'("        <ScatteringXS>")')

	do l=1,pl
	  do n=1,ngr

		 write(10,'((10x,300(1x,30000es13.5) ))') ( diff(iblk)%SCAT(o,n,l), o=f1(iblk,n,l),f2(iblk,n,l) )

	  enddo
	enddo

	write(10,'("        </ScatteringXS>")')
	write(10,'("      </material>")')
enddo

write(10,'("    </Macros>")')
write(10,'("</Materials>")')


write(10,'("    </Macros>")')
write(10,'("</Materials>")')

write(10,'("</INSTANT_INPUTS>")')

101 format('    <Macros NG="' ,i3, '">' ) 
102 format('      <material ID="',  i3, '" NA="',  i1, '" fissile="true">' )
103 format('      <material ID="',  i3, '" NA="',  i1, '" fissile="false">' )

close(10)


end subroutine writeins


end program DRAGONXS

