#! /usr/bin/env python 
# -*- coding: utf-8 -*-
###################################################################################
# Program   : DragSB
# Author    : Vincent Descotes, 7/07/2010 
# Purpose   : create a file in 'pwd' where all mixtures are numbered 
#             for the single block problem.
# ATTENTION : you need to provide manually the good number of cells in GEO:
#             (by modifying this script, line 174). At least, verify it.
# Input     : Nbg : int : number of groups for the condensation
# Output    : file fuel_cell_XXXgr_f.x2m in current directory. Ready to run.
###################################################################################
def DragSB(Nbg):
  import os
  import numpy

  # Number of groups for the condensation :
  gr=[Nbg]

  #Opening file supercell_XXXgr_33r.x2m for writing
  INPTPATH = os.getcwd()
  f = open(INPTPATH+'/fuel_cell_'+str(gr[0])+'gr_f.x2m', 'w')

  # Header in DRAGON
  f.write("*--------------------------------------------------------------------\n")
  f.write("* DB-VHTR Fuel Block Lattice calculation\n")
  f.write("* Fresh fuel TRU loading\n")
  f.write("* Author : V. Descotes\n")
  f.write("* Core corner block(6,1), no BP, no CR.\n")
  f.write("* JEFF3.1.0\n")  
  f.write("* SHEM295 Group Structure\n\n") 
  f.write("*--------------------------------------------------------------------\n")  
  f.write("*  Define STRUCTURES and MODULES used\n")
  f.write("*-------------------------------------------------------------------- \n")

  # Structures and modules in DRAGON

  f.write('LINKED_LIST \n')
  f.write('   LIBRARY LIBRARY2 GEOM SYS FLUX CPO\n')
  f.write("   OUTFUEL ;\n\n")

  f.write("XSM_FILE TRACK1 ;\n")

  f.write("SEQ_ASCII Multicompo Multicompo26 \n")
  f.write("          Outfuel Outfuel26 ;\n")

  f.write("MODULE\n")
  f.write("  GEO: LIB: ASM: FLU: EDI: DELETE: END:\n")
  f.write("  COMPO: USS: EXCELT: SYBILT: MCCGT: NCR: ;\n\n")

  f.write("*--------------------------------------------------------------------\n")
  f.write("* INITIALIZATION OF THE COMPO LCM OBJECTS\n")
  f.write("*--------------------------------------------------------------------\n\n")

  f.write("CPO := Multicompo ;\n\n")

  # Association of a mixture number to each element of each block
  f.write("*--------------------------------------------------------------------\n")
  f.write("* CREATION OF THE LIBRARY \n")
  f.write("*--------------------------------------------------------------------\n\n")
    
  f.write("LIBRARY := NCR: CPO ::\n")
  f.write("EDIT 0 NMIX 6\n")
  f.write("   COMPO CPO 'F'\n")
  f.write("* First mixture for the fuel pellet\n")
  f.write("   MIX  1 FROM 1 ENDMIX\n")
  f.write("* Second mixture for helium + graphite surrounding the fuel pellet\n")
  f.write("   MIX  2 FROM 2 ENDMIX\n\n")

  f.write("   COMPO CPO 'K'\n")
  f.write("* Mixture for small coolant\n")
  f.write("   MIX  3 FROM 1 ENDMIX\n\n")

  f.write("   COMPO CPO 'C'\n")
  f.write("* Mixture for large coolant\n")
  f.write("   MIX  4 FROM 1 ENDMIX\n\n")

  f.write("   COMPO CPO 'G'\n")
  f.write("* Mixture for the full graphite cells and burnable poisons (graphite here)\n")
  f.write("   MIX  5 FROM 1 ENDMIX\n\n")

  f.write("   COMPO CPO 'J'\n")
  f.write("* Mixture for the J-cells (graphite)\n")
  f.write("   MIX 6 FROM 1 ENDMIX\n")
  f.write(";\n\n")

  f.write("CPO := DELETE: CPO ;\n")

  #
  # Write the GEO part
  #

  f.write("*--------------------------------------------------------\n")
  f.write("*  GEOMETRY\n")
  f.write("*--------------------------------------------------------\n")
  f.write("* ----\n")
  f.write("* F = Fuel cell\n")
  f.write("* C = coolant hole cell (large)\n")
  f.write("* K = coolant hole cell (small)\n")
  f.write("* G = Full density graphite cell\n")
  f.write("* J = Reduced density graphite cell\n")
  f.write("* ----\n\n")

  f.write("GEOM := GEO: :: HEX 42\n")
  f.write("  EDIT 0\n")
  f.write("  HBC S30 REFL\n")
  f.write("  CELL\n")
  f.write("* Ring 0\n")
  f.write("G\n")
  f.write("* Ring 1\n")
  f.write("G\n")
  f.write("* Ring 2\n")
  f.write("K F\n")
  f.write("* Ring 3\n")
  f.write("F C\n")
  f.write("* Ring 4\n")
  f.write("C F F\n")
  f.write("* Ring 5\n")
  f.write("F C F\n")
  f.write("* Ring 6\n")
  f.write("C F F C\n")
  f.write("* Ring 7\n")
  f.write("F C F F\n")
  f.write("* Ring 8\n")
  f.write("C F F C F\n")
  f.write("* Ring 9\n")
  f.write("F C F F C\n")
  f.write("* Ring 10\n")
  f.write("C F F C F G\n")
  f.write("* Ring 11\n")
  f.write("J J J J J J\n")
  f.write("\n")
  #
  # Write the subgeometries
  #
  f.write("*--------------------------------------------------------------------\n")
  f.write("* Cell Definitions\n")
  f.write("*--------------------------------------------------------------------\n")
  f.write("*\n")

  f.write("*  Fuel Cell          (block of interest) --------------------------- \n")
  f.write(" ::: F := GEO: HEXCEL 1\n")
  f.write("     SIDE 1.08542 \n")
  f.write("     RADIUS 0.0 0.6225 \n")
  f.write("     SECT -1 \n")
  f.write("     MIX "+(" 1 ")*6+"\n")
  f.write("         "+(" 2 ")*6+";\n")

  f.write("*  Small coolant Hole (block of interest) ------------------  \n")
  f.write(" ::: K := GEO: HEX 1\n")
  f.write("     SIDE 1.08542 \n")
  f.write("     MIX 3 ;\n")

  f.write("*  Large Coolant Hole (block of interest) ------------------\n")
  f.write(" ::: C := GEO: HEX 1\n")
  f.write("     SIDE 1.08542 \n")
  f.write("     MIX  4 ;\n")

  f.write("*  Full Density Grapite (block of interest) ------------------\n")
  f.write(" ::: G := GEO: HEX 1\n")
  f.write("     SIDE 1.08542 \n")
  f.write("     MIX 5 ;\n")

  f.write("*  Lower Boundary Density Graphite (for testing only) ------------------\n")
  f.write(" ::: J := GEO: HEX 1\n")
  f.write("     SIDE 1.08542 \n")
  f.write("     MIX 6 ;\n")
  f.write(";\n\n\n")

  #
  # Write the tracking, self-shielding and flux calculation parts
  #

  f.write("*--------------------------------------------------------------------\n")
  f.write("*  Use SYBILT, USS, ASM and FLU for flux solution\n")
  f.write("*--------------------------------------------------------------------\n\n")
  f.write("***\n")
  f.write("* Tracking SYBILT\n") 
  f.write("***\n")

  f.write("TRACK1 := SYBILT: GEOM ::\n")
  f.write("    EDIT 2\n")
  f.write("    MAXR 40000\n")
  f.write("    MAXZ 500000\n")
  f.write("    QUA2 4 8\n")
  f.write("    QUAB 5 HEBE\n")
  f.write("    DP01  \n")
  f.write(";\n")  
    
  f.write("*---\n")
  f.write("*  Multigroup Flux Calculation\n")
  f.write("*---\n")
  f.write(" SYS := ASM: LIBRARY TRACK1 :: \n")
  f.write("  EDIT 0 ARM PNOR HELI ;\n")
  f.write("\n")
  f.write(" FLUX := FLU: SYS LIBRARY TRACK1 ::\n")
  f.write("  EDIT 2 \n")
  f.write("  TYPE K P1 EXTE 100 1E-5 THER 10 1E-5 ;\n")
  f.write("\n")
  f.write("SYS := DELETE: SYS ; \n\n")

  #
  # Write the edition part
  #   
  #
  f.write("*---\n")
  f.write("* Solution for Instant calculations :\n")
  f.write("*---\n\n")

  # Homogenized mixture 1 : F01, K01, C01, B01, G01, J01
  for g in gr:

      f.write("*************\n")
      f.write("*"+str(g)+" Groups *\n")
      f.write("*************\n\n")

      f.write("OUTFUEL := EDI: FLUX LIBRARY TRACK1 GEOM ::\n")
      f.write("  EDIT 3\n")
      f.write("  MERG MIX 1 1 1 1 1 1\n")
      
  #  Group condensations :
      if g==295:
	f.write("  COND NONE\n")
      
      elif g==26:
          f.write("  COND 7.408E+06 3.679E+06 6.721E+05 1.111E+05\n")
          f.write("       1.931E+04 3.355E+03 1.585E+03 7.485E+02\n")
          f.write("       2.754E+02 1.301E+02 6.144E+01   29.0\n")
          f.write("       13.70      8.32     5.04       2.38\n")
          f.write("        1.29      0.65     0.35       0.20\n")
          f.write("        0.12      0.08     0.05       0.02\n")
          f.write("        0.01\n")
      
      elif g==23:
	  f.write("  COND 3.679E+06 1.353E+06 5.000E+05 1.110E+05\n")
	  f.write("       6.738E+04 9.118E+03 3.673E+02  4.0\n")
	  f.write("       1.5         1.097    1.045    0.97\n")
	  f.write("       0.85        0.50     0.40     0.35\n")
	  f.write("       0.30        0.25     0.18     0.14\n")
	  f.write("       0.10        0.05\n")
      
      elif g==13:
	  f.write("  COND 1.8315E+05 1.014E+03 1.6745E+01 4.1293\n")
	  f.write("          2.13      1.305      0.79    0.62501\n")
	  f.write("         0.391      0.3145     0.115   5.9E-04\n")

      elif g==10:
	  f.write("  COND 1.8315E+05 1.014E+03 1.6745E+01 4.1293\n")
	  f.write("          2.13       0.79      0.391   0.3145\n")
	  f.write("         0.115   5.9E-04\n")

      elif g==9:
	  f.write("  COND 1.83E+05  9.61E+02     1.76E+01   3.93\n")
	  f.write("          2.38    1.275        0.825     0.13\n")      
      
      elif g==6:
	  f.write("  COND 1.8315E+05   1.6745E+01     2.13   0.62501\n")
	  f.write("       0.115\n")
      
      
      elif g==4:
	  f.write("  COND 1.111E+05 29.0 1.86\n")
      
      elif g==2:
	  f.write("  COND 2.38\n")
      else :
	  print ("This number of groups wasn't expected, go back to the program")
          raise NameError
      f.write("  MICR 16 GRAB HE4 O16 NP27 PU38 PU39 PU40\n")
      f.write("          PU41 PU42 AM41 AM42 AM43 C12 SI28 SI29 SI30\n")
      f.write("  SAVE\n")
      f.write(";\n\n")

      f.write("TRACK1 := DELETE: TRACK1 ; \n\n")
      f.write("Outfuel := OUTFUEL ;\n\n")
      f.write("OUTFUEL := DELETE: OUTFUEL ; \n")

      f.write("END: ;\n")
      f.write('QUIT "LIST" .\n')

  f.close()
  print "End of DragSB.py with : "+str(Nbg)+" groups."
# make it run as a script

if __name__ == "__main__":
    import sys
    DragSB(int(sys.argv[1]))

#end

