#! /usr/bin/env python 
# -*- coding: utf-8 -*-
###################################################################################
# Program   : DragSupCell
# Author    : Vincent Descotes, 7/07/2010 
# Purpose   : create a file in 'pwd' where all mixtures are numbered 
#             for the supercell problem.
# ATTENTION : you need to provide manually the good number of cells in GEO:
#             (by modifying this script, line 174). At least, verify it.
# Input     : Nbg : int : number of groups for the condensation
# Output    : file supercell_XXXgr_33r.x2m.txt in current directory. Ready to run.
###################################################################################
def DragSupCell(Nbg):
  import os
  import numpy
  #Number of fuel cells FXX
  NF = 10
  #Number of coolant cells CXX
  NC = 10
  #Number of small coolant cells KXX
  NK = 10
  #Number of normal graphite cells GXX
  NG = 13
  #Number of graphite J cells JXX
  NJ = 13
  #Number of burnable poison cells BXX
  NB = 10

  #Count total number of mixtures
  NTOT = NF*2+NC+NK+NG+NJ+NB

  # Number of groups for the condensation :
  gr=[Nbg]

  #Opening file supercell_XXXgr_33r.x2m for writing
  INPTPATH = os.getcwd()
  f = open(INPTPATH+'/supercell_'+str(gr[0])+'gr_33r.x2m', 'w')
  # Opening file with the cell repartition (output of buildsupercell_n18_33r.f)
  fs = open(INPTPATH+'/list', 'r') 

  # Header in DRAGON
  f.write("*--------------------------------------------------------------------\n")
  f.write("* DB-VHTR Fuel Block Supercell - 33 rings of hexes\n")
  f.write("* Fresh fuel TRU loading\n")
  f.write("* V. Descotes\n")
  f.write("* Core corner block(6,1), no BP, no CR.\n")
  f.write("* JEFF3.1.0\n")  
  f.write("* SHEM295 Group Structure -> condensed to 26 groups (SB_MOC)\n\n") 
  f.write("*--------------------------------------------------------------------\n")  
  f.write("*  Define STRUCTURES and MODULES used\n")
  f.write("*-------------------------------------------------------------------- \n")

  # Structures and modules in DRAGON

  f.write('LINKED_LIST \n')
  f.write('   LIBRARY LIBRARY2 GEOM SYS FLUX CPO\n')
  f.write("   OUT1 OUT2 OUT3 ;\n\n")

  f.write("XSM_FILE TRACK1 ;\n")
  f.write("SEQ_BINARY TRACK_FIL1 ;\n\n")

  f.write("SEQ_ASCII Multicompo26 Out1 Out2 Out3 ;\n")

  f.write("MODULE\n")
  f.write("  GEO: EXCELT: MCCGT: LIB: ASM: FLU: EDI: DELETE: END: NCR: ;\n\n")

  # Initialization of the Compo LCM objet
  f.write("*--------------------------------------------------------------------\n") 
  f.write("* INITIALIZATION OF THE COMPO LCM OBJECTS\n")
  f.write("*--------------------------------------------------------------------\n\n")

  f.write("CPO := Multicompo26 ;\n\n")

  # Association of a mixture number to each element of each block
  f.write("*--------------------------------------------------------------------\n")
  f.write("* ENTER DATA INTO COMPO LCM OBJECT \n")
  f.write("*--------------------------------------------------------------------\n\n")
    
  f.write('LIBRARY := NCR: CPO ::\n')
  s=str(NTOT)
  f.write('EDIT 0 NMIX '+str(NTOT)+'\n')

  f.write("   COMPO CPO 'F'\n")
  f.write("\n* First mixture for the fuel pellet\n")
  i=1
  while i<=NF:
      s=str(i)
      f.write('   MIX  ')
      f.write(s)
      f.write(' FROM 1 ENDMIX\n')
      i=i+1
  f.write("\n* Second mixture for helium + graphite surrounding the fuel pellet\n")
  j=1
  while j<=NF:
      s=str(i)
      f.write('   MIX  ')
      f.write(s)
      f.write(' FROM 2 ENDMIX\n')
      i=i+1
      j=j+1

  f.write("\n   COMPO CPO 'K'\n")
  f.write("\n* Mixture for small coolant\n")
  j=1
  while j<=NK:
      s=str(i)
      f.write('   MIX  ')
      f.write(s)
      f.write(' FROM 1 ENDMIX\n')
      i=i+1
      j=j+1

  f.write("\n   COMPO CPO 'C'\n")
  f.write("\n* Mixture for large coolant\n")
  j=1
  while j<=NC:
      s=str(i)
      f.write('   MIX  ')
      f.write(s)
      f.write(' FROM 1 ENDMIX\n')
      i=i+1
      j=j+1

  # Mixtures for B cells --> graphite for the moment
  f.write("\n   COMPO CPO 'G'\n")
  f.write("\n* Mixture for the burnable poison cells (graphite here)\n")
  j=1
  while j<=NB:
      s=str(i)
      f.write('   MIX  ')
      f.write(s)
      f.write(' FROM 1 ENDMIX\n')
      i=i+1
      j=j+1

  f.write("\n   COMPO CPO 'G'\n\n")
  f.write("* Mixture for the full graphite cells\n")
  j=1
  while j<=NG:
      s=str(i)
      f.write('   MIX  ')
      f.write(s)
      f.write(' FROM 1 ENDMIX\n')
      i=i+1
      j=j+1

  f.write("\n   COMPO CPO 'J'\n")
  f.write("\n* Mixture for the J-cells (graphite)\n")
  j=1
  while j<=NJ:
      s=str(i)
      f.write('   MIX  ')
      f.write(s)
      f.write(' FROM 1 \n')
      f.write('    MICRO ALL\n')
      f.write('    GRAB  9.486753785E-02 \n')
      f.write('   ENDMIX\n')
      i=i+1
      j=j+1

  f.write(";")
  f.write("\n")
  f.write("\n")
  #
  # Write the GEO part
  #

  f.write("*--------------------------------------------------------\n")
  f.write("*             SUPERCELL SPECIFICATION\n")
  f.write("*--------------------------------------------------------\n")
  f.write("* ----\n")
  f.write("* F = Fuel cell\n")
  f.write("* C = coolant hole cell (large)\n")
  f.write("* K = coolant hole cell (small)\n")
  f.write("* G = Full density graphite cell\n")
  f.write("* J = Reduced/increased density graphite cell\n")
  f.write("* ----\n\n")

  f.write("GEOM := GEO: :: HEX 3367\n")
  f.write("  EDIT 0\n")
  f.write("  HBC COMPLETE REFL\n")
  f.write("  CELL\n")
  # Copy the file list that contains the cell repartition.
  txt = "1"
  while txt != "":
    txt = fs.readline()
    f.write(txt)
  fs.close() # The "list" file is now closed.

  #
  # Write the subgeometries
  #
  f.write("*\n")
  f.write("*--------------------------------------------------------------------\n")
  f.write("* Cell Definitions\n")
  f.write("*--------------------------------------------------------------------\n")
  f.write("*\n")

  f.write("*  Fuel Cell FXX --------------------------- \n")
  i=1
  j=1
  while j<=NF:
      if j<10:
	  f.write(" ::: F0"+str(j)+" := GEO: HEXCEL 1\n")
      else:
	  f.write(" ::: F"+str(j)+" := GEO: HEXCEL 1\n")
      f.write("     SIDE 1.08542 \n")
      f.write("     RADIUS 0.0 0.6225\n")
      f.write("     SECT -1 \n")
      f.write("     MIX "+(str(i)+" ")*6+"\n")
      f.write("         "+(str(i+NF)+" ")*6+" ;\n")
      j=j+1
      i=i+1

  i=i+NF # pour passer les deux autres rangees concernant le fuel.

  f.write("*  Small coolant Hole KXX ------------------  \n")
  j=1
  while j<=NK:
      if j<10:
	  f.write(" ::: K0"+str(j)+" := GEO: HEXCEL 1\n")
      else:
	  f.write(" ::: K"+str(j)+" := GEO: HEXCEL 1\n")
      f.write("     SIDE 1.08542 \n")
      f.write("     RADIUS 0.0 0.4\n")
      f.write("     SECT -1 \n")
      f.write("     MIX "+(str(i)+" ")*6+"\n")
      f.write("         "+(str(i)+" ")*6+" ;\n")
      j=j+1
      i=i+1


  f.write("*  Large Coolant Hole CXX ------------------\n")
  j=1
  while j<=NC:
      if j<10:
	  f.write(" ::: C0"+str(j)+" := GEO: HEXCEL 1\n")
      else:
	  f.write(" ::: C"+str(j)+" := GEO: HEXCEL 1\n")
      f.write("     SIDE 1.08542 \n")
      f.write("     RADIUS 0.0 0.4\n")
      f.write("     SECT -1 \n")
      f.write("     MIX "+(str(i)+" ")*6+"\n")
      f.write("         "+(str(i)+" ")*6+" ;\n")
      j=j+1
      i=i+1

  f.write("*  Burnable poison cells BXX (GRA here) ---- \n")
  j=1
  while j<=NB:
      if j<10:
	  f.write(" ::: B0"+str(j)+" := GEO: HEXCEL 1\n")
      else:
	  f.write(" ::: B"+str(j)+" := GEO: HEXCEL 1\n")
      f.write("     SIDE 1.08542 \n")
      f.write("     RADIUS 0.0 0.4\n")
      f.write("     SECT -1 \n")
      f.write("     MIX "+(str(i)+" ")*6+"\n")
      f.write("         "+(str(i)+" ")*6+" ;\n")
      j=j+1
      i=i+1

  f.write("*  Full Density Grapite GXX ---------------- \n")
  j=1
  while j<=NG:
      if (j)<10:
	  f.write(" ::: G0"+str(j)+" := GEO: HEXCEL 1\n")
	  f.write("     SIDE 1.08542 \n")
	  f.write("     RADIUS 0.0 0.4\n")
	  f.write("     SECT -1 \n")
	  f.write("     MIX "+(str(i)+" ")*6+"\n")
	  f.write("         "+(str(i)+" ")*6+" ;\n")
      else:
	  f.write(" ::: G"+str(j)+" := GEO: HEXCEL 1\n")
	  f.write("     SIDE 1.08542 \n")
	  f.write("     RADIUS 0.0 0.4\n")
	  f.write("     SECT -1 \n")
	  f.write("     MIX "+(str(i)+" ")*6+"\n")
	  f.write("         "+(str(i)+" ")*6+" ;\n")
      j=j+1
      i=i+1

  f.write("*  Reduced/increased Density Graphite JXX -- \n")
  j=1
  while j<=NJ:
      if (j)<10:
	  f.write(" ::: J0"+str(j)+" := GEO: HEXCEL 1\n")
	  f.write("     SIDE 1.08542 \n")
	  f.write("     RADIUS 0.0 0.4\n")
	  f.write("     SECT -1 \n")
	  f.write("     MIX "+(str(i)+" ")*6+"\n")
	  f.write("         "+(str(i)+" ")*6+" ;\n")
      else:
	  f.write(" ::: J"+str(j)+" := GEO: HEXCEL 1\n")
	  f.write("     SIDE 1.08542 \n")
	  f.write("     RADIUS 0.0 0.4\n")
	  f.write("     SECT -1 \n")
	  f.write("     MIX "+(str(i)+" ")*6+"\n")
	  f.write("         "+(str(i)+" ")*6+" ;\n")
      j=j+1
      i=i+1

  f.write(";\n\n\n")

  #
  # Write the tracking and flux calculation part
  #

  f.write("*--------------------------------------------------------------------\n")
  f.write("*  Use EXCELT, MCCGT, ASM and FLU for flux solution\n")
  f.write("*--------------------------------------------------------------------\n\n")
  f.write("***\n")
  f.write("* Tracking EXCELT-MCCGT\n") 
  f.write("***\n")
  f.write("TRACK1 TRACK_FIL1 := EXCELT: GEOM ::\n")
  f.write("    EDIT 1\n")
  f.write("    MAXR 500000\n")
  f.write("    ANIS 1\n")
  f.write("    ALLG\n")
  f.write("    QUAB 5 HEBE\n")
  f.write("    PISO  \n")
  f.write("    TRAK TISO 4 10.0\n")
  f.write(";\n")      
  f.write("TRACK1 := MCCGT: TRACK1 TRACK_FIL1 GEOM ::     \n")
  f.write("     EDIT 0  LCMD 3\n")
  f.write("     EPSI 5E-5\n")
  f.write("     MAXI 100 KRYL 10 SCR 1 AAC 1 TMT\n")
  f.write(";\n\n")

  f.write("*---\n")
  f.write("*  Multigroup Flux Calculation\n")
  f.write("*---\n")
  f.write(" SYS := ASM: LIBRARY TRACK1 TRACK_FIL1 :: \n")
  f.write("  EDIT 0 ARM PNOR HELI ;\n")
  f.write("\n")
  f.write(" FLUX := FLU: SYS LIBRARY TRACK1 TRACK_FIL1 ::\n")
  f.write("  EDIT 2 \n")
  f.write("  TYPE K P1 EXTE 100 1E-5 THER 10 1E-5 ;\n")
  f.write("\n")
  f.write("TRACK_FIL1 := DELETE: TRACK_FIL1 ;\n")
  f.write("\n")
  f.write("SYS := DELETE: SYS ; \n\n")

  #
  # Write the first part of EDI:
  #   
  #
  f.write("*---\n")
  f.write("* Solution for Instant calculation :\n")
  f.write("* -> homogenize all regions of the central block\n")
  f.write("*---\n\n")

  f.write('*---\n')
  f.write('* Mixtures merge for Instant :\n')
  f.write('* Fuel cell 01 merged\n')
  f.write('*---\n\n')

  # Homogenized mixture 1 : F01, K01, C01, B01, G01, J01
  for g in gr:

      f.write("*************\n")
      f.write("*"+str(g)+" Groups *\n")
      f.write("*************\n\n")

      f.write("OUT1 := EDI: FLUX LIBRARY TRACK1 GEOM ::\n")
      f.write("   EDIT 3\n")
      f.write("   MERGE MIX\n")
      f.write("*1 2 3 4 5 6 7 8 9 10\n")
      k=1
      f.write("* F mixtures : fuel pellet\n")
      while k<=NF:
	  if k==1:
	      f.write(" 1")
	      if k==10:
		  f.write("\n")
	  else:
	      f.write(" 0")
	      if k==10:
		  f.write("\n")
	  k=k+1
      f.write("\n")
      k=1
      f.write("* F mixtures : helium and graphite surrounding fuel pellet\n")
      while k<=NF:
	  if k==1:
	      f.write(" 1")
	      if k==10:
		  f.write("\n")
	  else:
	      f.write(" 0")
	      if k==10:
		  f.write("\n")
	  k=k+1
      f.write("\n")
      k=1
      f.write("* K mixtures\n")
      while k<=NK:
	  if k==1:
	      f.write(" 1")
	      if k==10:
		  f.write("\n")
	  else:
	      f.write(" 0")
	      if k==10:
		  f.write("\n")
	  k=k+1
      f.write("\n")
      k=1
      f.write("* C mixtures\n")
      while k<=NC:
	  if k==1:
	      f.write(" 1")
	      if k==10:
		  f.write("\n")
	  else:
	      f.write(" 0")
	      if k==10:
		  f.write("\n")
	  k=k+1
      f.write("\n")
      k=1
      f.write("* B mixtures\n")
      while k<=NB:
	  if k==1:
	      f.write(" 1")
	      if k==10:
		  f.write("\n")
	  else:
	      f.write(" 0")
	      if k==10:
		  f.write("\n")
	  k=k+1
      f.write("\n")
      k=1
      f.write("* G mixtures\n")
      while k<=NG:
	  if k==1:
	      f.write(" 1")
	      if k==10:
		  f.write("\n")
	  else:
	      f.write(" 0")
	      if k==10:
		  f.write("\n")
	  k=k+1
      f.write("\n")
      k=1
      f.write("* J mixtures\n")
      while k<=NJ:
	  if k==1:
	      f.write(" 1")
	      if k==10:
		  f.write("\n")
	  else:
	      f.write(" 0")
	      if k==10:
		  f.write("\n")
	  k=k+1

      f.write("\n")
  #  Group condensations :
      if g==26:
	f.write("  COND NONE\n")
      
  #    elif g==26:
  #        f.write("  COND 7.408E+06 3.679E+06 6.721E+05 1.111E+05\n")
  #        f.write("       1.931E+04 3.355E+03 1.585E+03 7.485E+02\n")
  #        f.write("       2.754E+02 1.301E+02 6.144E+01   29.0\n")
  #        f.write("       13.70      8.32     5.04       2.38\n")
  #        f.write("        1.29      0.65     0.35       0.20\n")
  #        f.write("        0.12      0.08     0.05       0.02\n")
  #        f.write("        0.01\n")
      
      elif g==10:
	  f.write("  COND 1.8315E+05 1.014E+03 1.6745E+01 4.1293\n")
	  f.write("          2.13       0.79     0.391    0.3145 \n")
	  f.write("          0.115     5.9E-04\n")

      elif g==9:
	  f.write("  COND 1.83E+05    9.61E+02   1.76E+01  3.93\n")
	  f.write("          2.38       1.275     0.825    0.13 \n")
      
      elif g==6:
	  f.write("  COND 1.8315E+05   1.6745E+01     2.13   0.62501\n")
	  f.write("       0.115\n")
      
      elif g==4:
	  f.write("  COND 1.111E+05 29.0 1.86\n")
      
      elif g==2:
	  f.write("  COND 2.38\n")
      else :
	  print ("This number of groups wasn't expected, go back to the program")
          raise NameError
      f.write("  MICR 16 GRAB HE4 O16 NP27 PU38 PU39 PU40\n")
      f.write("          PU41 PU42 AM41 AM42 AM43 C12 SI28 SI29 SI30\n")
      f.write("  SAVE\n")
      f.write(";\n\n")

      f.write("Out1 := OUT1 ;\n\n")
      f.write("OUT1 := DELETE: OUT1 ; \n")
      f.write("TRACK1 := DELETE: TRACK1 ; \n\n")
      f.write("END: ; \n")
      f.write('QUIT "LIST" .\n')

  f.close()
  print "End of DragSupCell.py with : "+str(Nbg)+" groups."
# make it run as a script

if __name__ == "__main__":
    import sys
    DragSupCell(int(sys.argv[1]))

#end

