#! /usr/bin/env python
# -*- coding: utf-8 -*-

# Program : num_mix
# Author : Vincent Descotes, 7/07/2010 
# Purpose : create a file in ~/VHTR_3B where all mixtures are numbered 
#           for the supercell problem
# Input : none
# Output : file num_list.txt in ~/VHTR_3
import os
import numpy
#Number of fuel cells FXX
NF = 10
#Number of coolant cells CXX
NC = 10
#Number of small coolant cells KXX
NK = 10
#Number of normal graphite cells GXX
NG = 13
#Number of graphite J cells JXX
NJ = 13
#Number of burnable poison cells BXX
NB = 10

#Count total number of mixtures
NTOT = NF*2+NC+NK+NG+NJ+NB

# Number of groups for the condensation :
gr=[295]

#Opening file num_list.txt
INPTPATH = os.getcwd()
f = open(INPTPATH+'/num_list.txt', 'w')

# LINKED_LIST IN DRAGON

f.write('LINKED_LIST \n')
f.write('   LIBRARY LIBRARY2 GEOM SYS FLUX CPO\n')
out=range(1,4)
f.write('   ')
for i in out:
    f.write('OUT'+str(i)+' ')
    if i==5 or i==10 or i==14:
        f.write('\n')
        f.write('   ')
f.write('\n')
f.write(';\n\n')

f.write("XSM_FILE TRACK1 ; \n\n")
f.write("SEQ_BINARY TRACK_FIL1 ; \n\n")
# SEQ_ASCII IN DRAGON

f.write('SEQ_ASCII')
f.write(' Multicompo26\n')
out=range(1,4)
f.write('           ')
for i in out:
    f.write('Out'+str(i)+' ')
    if i==5 or i==10 or i==14:
        f.write('\n')
        f.write('           ')
f.write('\n')
f.write(';\n\n')


#Association of a mixture number to each element of each block

f.write('LIBRARY := NCR: CPO ::\n')
s=str(NTOT)
f.write('EDIT 0 NMIX ')
f.write(s)
f.write("\n")

f.write("   COMPO CPO 'F'\n")
f.write("\n* First mixture for the fuel pellet\n")
i=1
while i<=NF:
    s=str(i)
    f.write('   MIX  ')
    f.write(s)
    f.write(' FROM 1 ENDMIX\n')
    i=i+1
f.write("\n* Second mixture for helium + graphite surrounding the fuel pellet\n")
j=1
while j<=NF:
    s=str(i)
    f.write('   MIX  ')
    f.write(s)
    f.write(' FROM 2 ENDMIX\n')
    i=i+1
    j=j+1
f.write("\n   COMPO CPO 'K'\n")
f.write("\n* Mixture for small coolant\n")
j=1
while j<=NK:
    s=str(i)
    f.write('   MIX  ')
    f.write(s)
    f.write(' FROM 1 ENDMIX\n')
    i=i+1
    j=j+1
f.write("\n   COMPO CPO 'C'\n")
f.write("\n* Mixture for large coolant\n")
j=1
while j<=NC:
    s=str(i)
    f.write('   MIX  ')
    f.write(s)
    f.write(' FROM 1 ENDMIX\n')
    i=i+1
    j=j+1

# Mixtures for B cells --> graphite for the moment

f.write("\n   COMPO CPO 'G'\n")
f.write("\n* Mixture for the burnable poisons cells (graphite here)\n")
j=1
while j<=NB:
    s=str(i)
    f.write('   MIX  ')
    f.write(s)
    f.write(' FROM 1 ENDMIX\n')
    i=i+1
    j=j+1

f.write("\n   COMPO CPO 'G'\n\n")
f.write("* Mixture for the full graphite cells\n")
j=1
while j<=NG:
    s=str(i)
    f.write('   MIX  ')
    f.write(s)
    f.write(' FROM 1 ENDMIX\n')
    i=i+1
    j=j+1
f.write("\n   COMPO CPO 'J'\n")
f.write("\n* Mixture for the J-cells (graphite)\n")
j=1
while j<=NJ:
    s=str(i)
    f.write('   MIX  ')
    f.write(s)
    f.write(' FROM 1 \n')
    f.write('    MICRO ALL\n')
    f.write('    GRAB  9.486753785E-02 \n')
    f.write('   ENDMIX\n')
    i=i+1
    j=j+1

f.write(";")
f.write("\n")
f.write("\n")

#
# Write the subgeometries
#

f.write("*  Fuel Cell FXX          (block of interest) \n")
i=1
j=1
while j<=NF:
     if j<10:
         f.write(" ::: F0"+str(j)+" := GEO: HEXCEL 1\n")
     else:
         f.write(" ::: F"+str(j)+" := GEO: HEXCEL 1\n")
     f.write("     SIDE 1.08542 \n")
     f.write("     RADIUS 0.0 0.6225\n")
     f.write("     SECT -1 \n")
     f.write("     MIX "+(str(i)+" ")*6+"\n")
     f.write("         "+(str(i+NF)+" ")*6+" ;\n")
     j=j+1
     i=i+1

i=i+NF # pour passer les deux autres rangees concernant le fuel.

f.write("*  Small coolant Hole KXX (block of interest) \n")
j=1
while j<=NK:
     if j<10:
         f.write(" ::: K0"+str(j)+" := GEO: HEXCEL 1\n")
     else:
         f.write(" ::: K"+str(j)+" := GEO: HEXCEL 1\n")
     f.write("     SIDE 1.08542 \n")
     f.write("     RADIUS 0.0 0.8\n")
     f.write("     SECT -1 \n")
     f.write("     MIX "+(str(i)+" ")*6+"\n")
     f.write("         "+(str(i)+" ")*6+" ;\n")
     j=j+1
     i=i+1


f.write("*  Large Coolant Hole CXX (block of interest) \n")
j=1
while j<=NC:
     if j<10:
         f.write(" ::: C0"+str(j)+" := GEO: HEXCEL 1\n")
     else:
         f.write(" ::: C"+str(j)+" := GEO: HEXCEL 1\n")
     f.write("     SIDE 1.08542 \n")
     f.write("     RADIUS 0.0 0.8\n")
     f.write("     SECT -1 \n")
     f.write("     MIX "+(str(i)+" ")*6+"\n")
     f.write("         "+(str(i)+" ")*6+" ;\n")
     j=j+1
     i=i+1

f.write("*  Burnable poison cells (block of interest, GRA here) \n")
j=1
while j<=NB:
     if j<10:
         f.write(" ::: B0"+str(j)+" := GEO: HEXCEL 1\n")
     else:
         f.write(" ::: B"+str(j)+" := GEO: HEXCEL 1\n")
     f.write("     SIDE 1.08542 \n")
     f.write("     RADIUS 0.0 0.8\n")
     f.write("     SECT -1 \n")
     f.write("     MIX "+(str(i)+" ")*6+"\n")
     f.write("         "+(str(i)+" ")*6+" ;\n")
     j=j+1
     i=i+1

f.write("*  Full Density Grapite GXX (block of interest) \n")
j=1
while j<=NG:
    if (j)<10:
        f.write(" ::: G0"+str(j)+" := GEO: HEXCEL 1\n")
        f.write("     SIDE 1.08542 \n")
        f.write("     RADIUS 0.0 0.8\n")
        f.write("     SECT -1 \n")
        f.write("     MIX "+(str(i)+" ")*6+"\n")
        f.write("         "+(str(i)+" ")*6+" ;\n")
    else:
        f.write(" ::: G"+str(j)+" := GEO: HEXCEL 1\n")
        f.write("     SIDE 1.08542 \n")
        f.write("     RADIUS 0.0 0.8\n")
        f.write("     SECT -1 \n")
        f.write("     MIX "+(str(i)+" ")*6+"\n")
        f.write("         "+(str(i)+" ")*6+" ;\n")
    j=j+1
    i=i+1

f.write("*  Reduced/increased Density Graphite JXX (block of interest) \n")
j=1
while j<=NJ:
    if (j)<10:
        f.write(" ::: J0"+str(j)+" := GEO: HEXCEL 1\n")
        f.write("     SIDE 1.08542 \n")
        f.write("     RADIUS 0.0 0.8\n")
        f.write("     SECT -1 \n")
        f.write("     MIX "+(str(i)+" ")*6+"\n")
        f.write("         "+(str(i)+" ")*6+" ;\n")
    else:
        f.write(" ::: J"+str(j)+" := GEO: HEXCEL 1\n")
        f.write("     SIDE 1.08542 \n")
        f.write("     RADIUS 0.0 0.8\n")
        f.write("     SECT -1 \n")
        f.write("     MIX "+(str(i)+" ")*6+"\n")
        f.write("         "+(str(i)+" ")*6+" ;\n")
    j=j+1
    i=i+1

f.write(";")
f.write("\n\n\n")
#
# Write the first part of EDI:
#   
#
f.write('*---\n')
f.write('* Mixtures merge for Instant :\n')
f.write('* Fuel cell 01 merged\n*---\n\n')

# Homogenized mixture 1 : F01, K01, C01, B01, G01, J01
for g in gr:

    f.write("*************\n")
    f.write("*"+str(g)+" Groups *\n")
    f.write("*************\n\n")

    f.write("OUT1 := EDI: FLUX LIBRARY TRACK1 GEOM ::\n")
    f.write("   EDIT 4\n")
    f.write("   MERGE MIX\n")
    f.write("*1 2 3 4 5 6 7 8 9 10\n")
    k=1
    f.write("* F mixtures : fuel pellet\n")
    while k<=NF:
        if k==1:
            f.write(" 1")
            if k==10:
                f.write("\n")
        else:
            f.write(" 0")
            if k==10:
                f.write("\n")
        k=k+1
    f.write("\n")
    k=1
    f.write("* F mixtures : helium and graphite surrounding fuel\n")
    while k<=NF:
        if k==1:
            f.write(" 1")
            if k==10:
                f.write("\n")
        else:
            f.write(" 0")
            if k==10:
                f.write("\n")
        k=k+1
    f.write("\n")
    k=1
    f.write("* K mixtures\n")
    while k<=NK:
        if k==1:
            f.write(" 1")
            if k==10:
                f.write("\n")
        else:
            f.write(" 0")
            if k==10:
                f.write("\n")
        k=k+1
    f.write("\n")
    k=1
    f.write("* C mixtures\n")
    while k<=NC:
        if k==1:
            f.write(" 1")
            if k==10:
                f.write("\n")
        else:
            f.write(" 0")
            if k==10:
                f.write("\n")
        k=k+1
    f.write("\n")
    k=1
    f.write("* B mixtures\n")
    while k<=NB:
        if k==1:
            f.write(" 1")
            if k==10:
                f.write("\n")
        else:
            f.write(" 0")
            if k==10:
                f.write("\n")
        k=k+1
    f.write("\n")
    k=1
    f.write("* G mixtures\n")
    while k<=NG:
        if k==1:
            f.write(" 1")
            if k==10:
                f.write("\n")
        else:
            f.write(" 0")
            if k==10:
                f.write("\n")
        k=k+1
    f.write("\n")
    k=1
    f.write("* J mixtures\n")
    while k<=NJ:
        if k==1:
            f.write(" 1")
            if k==10:
                f.write("\n")
        else:
            f.write(" 0")
            if k==10:
                f.write("\n")
        k=k+1

    f.write("\n\n")

    if g==295:
       f.write("  COND NONE\n")
    
    elif g==26:
        f.write("  COND 7.408E+06 3.679E+06 6.721E+05 1.111E+05\n")
        f.write("       1.931E+04 3.355E+03 1.585E+03 7.485E+02\n")
        f.write("       2.754E+02 1.301E+02 6.144E+01   29.0\n")
        f.write("       13.70      8.32     5.04       2.38\n")
        f.write("        1.29      0.65     0.35       0.20\n")
        f.write("        0.12      0.08     0.05       0.02\n")
        f.write("        0.01\n")
    
    elif g==23:
        f.write("  COND 3.679E+06 1.353E+06 5.000E+05 1.110E+05\n")
        f.write("       6.738E+04 9.118E+03 3.673E+02  4.0\n")
        f.write("       1.5         1.097    1.045    0.97\n")
        f.write("       0.85        0.50     0.40     0.35\n")
        f.write("       0.30        0.25     0.18     0.14\n")
        f.write("       0.10        0.05\n")
    
    elif g==13:
        f.write("  COND 1.8315E+05 1.014E+03 1.6745E+01 4.1293\n")
        f.write("          2.13      1.305      0.79    0.62501\n")
        f.write("         0.391      0.3145     0.115   5.9E-04\n")
    
    
    elif g==6:
        f.write("  COND 1.8315E+05   1.6745E+01     2.13   0.62501\n")
        f.write("       0.115\n")
    
    
    elif g==4:
        f.write("  COND 1.111E+05 29.0 1.86\n")
    
    elif g==2:
        f.write("  COND 2.38\n")
    else :
        print ("This number of groups wasn't expected, go back to the program")
        
    f.write("  MICR 16 GRAB HE4 O16 NP27 PU38 PU39 PU40\n")
    f.write("          PU41 PU42 AM41 AM42 AM43 C12 SI28 SI29 SI30\n")
    f.write("  SAVE\n")
    f.write(";\n\n")

    f.write("Out1 := OUT1 ;\n")
    f.write("OUT1 := DELETE: OUT1 ; \n\n")
    f.write("\n\n")

# Homogenized mixture 2 : G08, J08
#                         G09, J09
#                         G10, J10

    f.write("OUT2 := EDI: FLUX LIBRARY TRACK1 GEOM ::\n")
    f.write("   EDIT 4\n")
    f.write("   MERGE MIX\n")
    f.write("*1 2 3 4 5 6 7 8 9 10\n")
    k=1
    f.write("* F mixtures\n")
    while k<=NF*2:
        f.write(" 0")
        if numpy.remainder(k,NF)==0:
            f.write("\n")
        k=k+1
    k=1
    f.write("* K mixtures\n")
    while k<=NK:
        f.write(" 0")
        if numpy.remainder(k,NK)==0:
            f.write("\n")
        k=k+1
    k=1
    f.write("* C mixtures\n")
    while k<=NC:
        f.write(" 0")
        if numpy.remainder(k,NC)==0:
            f.write("\n")
        k=k+1
    k=1
    f.write("* B mixtures\n")
    while k<=NB:
        f.write(" 0")
        if k==10:
            f.write("\n")
        k=k+1
    f.write("\n")
    k=1
    f.write("* G mixtures\n")
    while k<=NG:
        if k==8 or k==9 or k==10:
            f.write(" 1")
            if k==10:
                f.write("\n")
        else:
            f.write(" 0")
            if k==10:
                f.write("\n")
        k=k+1
    f.write("\n")
    k=1
    f.write("* J mixtures\n")
    while k<=NJ:
        f.write(" 0")
        if k==10:
            f.write("\n")
        k=k+1

    f.write("\n\n")

    if g==295:
       f.write("  COND NONE\n")
    
    elif g==26:
        f.write("  COND 7.408E+06 3.679E+06 6.721E+05 1.111E+05\n")
        f.write("       1.931E+04 3.355E+03 1.585E+03 7.485E+02\n")
        f.write("       2.754E+02 1.301E+02 6.144E+01   29.0\n")
        f.write("       13.70      8.32     5.04       2.38\n")
        f.write("        1.29      0.65     0.35       0.20\n")
        f.write("        0.12      0.08     0.05       0.02\n")
        f.write("        0.01\n")
    
    elif g==23:
        f.write("  COND 3.679E+06 1.353E+06 5.000E+05 1.110E+05\n")
        f.write("       6.738E+04 9.118E+03 3.673E+02  4.0\n")
        f.write("       1.5         1.097    1.045    0.97\n")
        f.write("       0.85        0.50     0.40     0.35\n")
        f.write("       0.30        0.25     0.18     0.14\n")
        f.write("       0.10        0.05\n")
    
    elif g==13:
        f.write("  COND 1.8315E+05 1.014E+03 1.6745E+01 4.1293\n")
        f.write("          2.13      1.305      0.79    0.62501\n")
        f.write("         0.391      0.3145     0.115   5.9E-04\n")
    
    
    elif g==6:
        f.write("  COND 1.8315E+05   1.6745E+01     2.13   0.62501\n")
        f.write("       0.115\n")
    
    
    elif g==4:
        f.write("  COND 1.111E+05 29.0 1.86\n")
    
    elif g==2:
        f.write("  COND 2.38\n")
    else :
        print ("This number of groups wasn't expected, go back to the program")

    f.write("  MICR 16 GRAB HE4 O16 NP27 PU38 PU39 PU40\n")
    f.write("          PU41 PU42 AM41 AM42 AM43 C12 SI28 SI29 SI30\n")
    f.write("  SAVE\n")
    f.write(";\n\n")

    f.write("Out2 := OUT2 ;\n")
    f.write("OUT2 := DELETE: OUT2 ; \n\n")
    f.write("\n\n")

# Homogenized mixture 3 : G11, J11
#                         G12, J12
#                         G13, J13

    f.write("OUT3 := EDI: FLUX LIBRARY TRACK1 GEOM ::\n")
    f.write("   EDIT 4\n")
    f.write("   MERGE MIX\n")
    f.write("*1 2 3 4 5 6 7 8 9 10\n")
    k=1
    f.write("* F mixtures\n")
    while k<=NF*2:
        f.write(" 0")
        if k==10 or numpy.remainder(k,NF)==0:
            f.write("\n")
        k=k+1
    f.write("\n")
    k=1
    f.write("* K mixtures\n")
    while k<=NK:
        f.write(" 0")
        if k==10 or numpy.remainder(k,NK)==0:
            f.write("\n")
        k=k+1
    f.write("\n")
    k=1
    f.write("* C mixtures\n")
    while k<=NC:
        f.write(" 0")
        if k==10 or numpy.remainder(k,NC)==0:
            f.write("\n")
        k=k+1
    f.write("\n")
    k=1
    f.write("* B mixtures\n")
    while k<=NB:
        f.write(" 0")
        if k==10:
            f.write("\n")
        k=k+1
    f.write("\n")
    k=1
    k=1
    f.write("* G mixtures\n")
    while k<=NG:
        if k==11 or k==12 or k==13:
            f.write(" 1")
            if k==10:
                f.write("\n")
        else:
            f.write(" 0")
            if k==10:
                f.write("\n")
        k=k+1
    f.write("\n")
    k=1
    f.write("* J mixtures\n")
    while k<=NJ:
        f.write(" 0")
        if k==10:
            f.write("\n")
        k=k+1

    f.write("\n\n")

    if g==295:
       f.write("  COND NONE\n")
    
    elif g==26:
        f.write("  COND 7.408E+06 3.679E+06 6.721E+05 1.111E+05\n")
        f.write("       1.931E+04 3.355E+03 1.585E+03 7.485E+02\n")
        f.write("       2.754E+02 1.301E+02 6.144E+01   29.0\n")
        f.write("       13.70      8.32     5.04       2.38\n")
        f.write("        1.29      0.65     0.35       0.20\n")
        f.write("        0.12      0.08     0.05       0.02\n")
        f.write("        0.01\n")
    
    elif g==23:
        f.write("  COND 3.679E+06 1.353E+06 5.000E+05 1.110E+05\n")
        f.write("       6.738E+04 9.118E+03 3.673E+02  4.0\n")
        f.write("       1.5         1.097    1.045    0.97\n")
        f.write("       0.85        0.50     0.40     0.35\n")
        f.write("       0.30        0.25     0.18     0.14\n")
        f.write("       0.10        0.05\n")
    
    elif g==13:
        f.write("  COND 1.8315E+05 1.014E+03 1.6745E+01 4.1293\n")
        f.write("          2.13      1.305      0.79    0.62501\n")
        f.write("         0.391      0.3145     0.115   5.9E-04\n")
    
    
    elif g==6:
        f.write("  COND 1.8315E+05   1.6745E+01     2.13   0.62501\n")
        f.write("       0.115\n")
    
    
    elif g==4:
        f.write("  COND 1.111E+05 29.0 1.86\n")
    
    elif g==2:
        f.write("  COND 2.38\n")
    else :
        print ("This number of groups wasn't expected, go back to the program")

    f.write("  MICR 16 GRAB HE4 O16 NP27 PU38 PU39 PU40\n")
    f.write("          PU41 PU42 AM41 AM42 AM43 C12 SI28 SI29 SI30\n")
    f.write("  SAVE\n")
    f.write(";\n\n")

    f.write("Out3 := OUT3 ;\n")
    f.write("OUT3 := DELETE: OUT3 ; \n\n")
    f.write("\n\n")

f.close()













