#!/bin/bash
# Main script to perform the whole INSTANT calculation scheme in P3.
# Call : Core_calc_P3.sh -g<number of groups> -meth<0/1> -scat<0/1>
#        meth 0 : mimic diffusion; meth 1 : normal Pn.
#        scat 0 : isotropic scattering; scat 1 : linear anisotropic scattering.
# Attention, you must have pick up a node...
# (don't use the brackets <> in the call, and no space between g and the integer). Only 1 number of group allowed at a time.
echo "****************************************************"
echo "INSTANT CALCULATION SCHEME P3 : SC_moc295 path :"
echo "****************************************************"
echo "!!!"
echo "!!! Did you think to pick up a node before starting ???"
echo "!!!"
echo "Current directory for cross-sections (verify !)"
echo "        " `pwd`
echo "  "

DIR=`pwd`
DIR2=/home/descv/VHTR_SC_moc295
DIRXS=/home/descv/VHTR_SC_moc295/Full_core_P3/xs
NbG=""

if [ $DIR != $DIR2 ]; then
    echo "You must start from directory VHTR_SC_moc295"
    echo "Your are now in directory :" $DIR
    exit 1
fi

#Recover the number of groups wanted in the variable NbG, M (for meth) and S (for scat) :
for param in $*
do
    case $param in
        -g*) NbG="`echo $1 | cut -c 3-`" ;;
        -meth*) M="`echo $1 | cut -c 6-`" ;;
        -scat*) S="`echo $1 | cut -c 6-`" ;;  
    esac
    shift
done
echo "Number of groups taken : "$NbG
echo ""
echo "Method : "$M
echo "Scattering order : "$S 
echo ""
sleep 2s

# begin the script by copying the cross-sections :
echo "********************************************"
echo "Call the copying script for cross-sections :"
echo "********************************************"
echo ""

if [ $M = 0 ]; then
    echo " !!! WARNING !!!"
    echo "It is not a good idea to try to mimic diffusion with P3 !"
    echo "You declared meth 0, so I will stop the code. Change the option -meth and restart."
    exit 1
else
    ./copy_P3_void.sh -g$NbG
fi
sleep 2s

#Go into ./Full_core_P3 to pursue the task and create the DRAG2INSm.inp file
echo "*******************************"
echo "Go to Full_core_P3 directory  :"
echo "*******************************"
echo ""
cd ./Full_core_P3
pwd
echo ""

echo "**************************************"
echo "Create the input for DRAG2Insm3.f90  :"
echo "**************************************"
echo ""
./WriteDrag2InsInp.py $NbG $M $S
echo ""
sleep 2s

#Build the INSTANT inp.xml file.
echo "********************************************"
echo "Call the transfer script to build inp.xml  :"
echo "********************************************"
./transfer.sh
sleep 2s

#Move the inp.xml file into ./Instant_calc and go inside
echo "********************************************"
echo "Move new inp.xml into the Instant directory :"
echo "********************************************"
echo ""
mv -v inp.xml ./Instant_calc
cd ./Instant_calc
echo ""

#Clean this directory for the calculation
echo "************************************************"
echo "Clean the Instant directory before calculation :"
echo "************************************************"
rm *.vtk *.ps all_parameters.xml INSTANT.outp trash-*
echo "List all files inside the directory after cleaning :"
echo "      "`pwd`
echo ""
ls

echo ""
sleep 2s

#do the INSTANT calculation
echo "******************************"
echo "Do the INSTANT calculation :"
echo "******************************"
echo ""
echo "Number of groups : "$NbG
./instant inp.xml

echo "Time to notice the k-effective !"
echo ""
sleep 2s

#Move the interesting files : for the flux, the 3 first files and 3 last files. Attention with 4 and 2 groups, take all of them.
echo "*******************************************************"
echo "Move the interesting files into Results_P3/... :" $NbG
echo "*******************************************************"
RES=Results_P3/SupCell_$NbG"gr"

mv -v inp.xml ../$RES
mv -v FissionSource-p0.vtk ../$RES
mv -v Initial-Mesh-p0.vtk ../$RES
mv -v Initial-Mesh-p0.ps ../$RES
mv -v INSTANT.outp ../$RES

if [ "$NbG" = "2" ] || [ "$NbG" = "4" ]; then
   mv -v flux*-even1-p0.vtk ../$RES
else
   mv -v flux1-even1-p0.vtk ../$RES
   mv -v flux2-even1-p0.vtk ../$RES
   mv -v flux3-even1-p0.vtk ../$RES

   mv -v flux$NbG"-even1-p0.vtk" ../$RES
   NbG1=$[$NbG-1]
   NbG2=$[$NbG-2]
   mv -v flux$NbG1"-even1-p0.vtk" ../$RES
   mv -v flux$NbG2"-even1-p0.vtk" ../$RES
fi

#Go inside the result directory and check what has been transferred.
echo "*******************************************************"
echo "List the files transfered into Results_P3/... + keff :" $NbG
echo "*******************************************************"
echo ""
cd ../$RES

ls -l | cut -c 35-
echo ""
echo "Final INSTANT K-effective :"
grep 'k-eff=' INSTANT.outp | tail -n1
echo ""
echo "*******************************************************"
echo " End of the script Core_calc_P3.sh !"
echo "*******************************************************"

