#!/bin/bash
# Script copies cross-sections from VHTR_SC_syb to VHTR_SC_syb/Full_core_P1/xs/
# Call : copy.sh -g<number of groups>
# (don't use the brackets <> in the call, and no space between g and the integer). Only 1 number of group allowed at a time.

echo "Begin copy of homogenized cross-sections"
echo "from the single-block lattice calculation in DRAGON"
echo "        " `pwd`
echo "  "
DIR=`pwd`
DIR2=/home/descv/VHTR_SC_syb295
DIRXS=/home/descv/VHTR_SC_syb295/Full_core_P1/xs
NbG=""

if [ $DIR != $DIR2 ]; then
    echo "You must start from directory VHTR_SC_syb295"
    echo "Your are now in directory :" $DIR
    exit 1
fi

for param in $*
do
    case $param in
        -g*) NbG="`echo $1 | cut -c 3-`"     
    esac
    shift
done

echo "Copy of the fuel cross-section"
echo "Current directory for Fuel XS :"
echo "        " `pwd`

cd $DIR2/Cell_n13
# cell 13 : for XSOUT4 and XSOUT10
FUELXS=supercell_$NbG"gr_33r+Out1"
echo `pwd`
cp -v $FUELXS $DIRXS/XSOUT4.edi
cp -v $FUELXS $DIRXS/XSOUT10.edi
echo ""

cd $DIR2/Cell_n19
# cell 19 : for XSOUT5 and XSOUT11
echo `pwd`
cp -v $FUELXS $DIRXS/XSOUT5.edi
cp -v $FUELXS $DIRXS/XSOUT11.edi
echo ""

cd $DIR2/Cell_n18
# cell 18 : for XSOUT9
echo `pwd`
cp -v $FUELXS $DIRXS/XSOUT9.edi
echo ""

# cross-sections from SB for the inner part. We take them from the homogeneous path with the same multicompo.
cd ~/VHTR_SB_syb/HOM295/
echo "Cross-sections from the single block homogeneous calculation for the inner part of the fuel"
echo `pwd`
echo ""
FUELXS2=fuel_cell_$NbG"gr_f+Outfuel"

cp -v $FUELXS2 $DIRXS/XSOUT6.edi
cp -v $FUELXS2 $DIRXS/XSOUT7.edi
cp -v $FUELXS2 $DIRXS/XSOUT8.edi


# Go to catch the reflector cross-sections.
# As this script is for the P1 calculation with linear anisotropy, we go to Refl_void.

cd ~/VHTR_Refl_moc/Refl_void

echo "Copy of the reflector cross-sections for a P1 core calculation"
echo "Current directory for reflector XS : P1 with linear anisotropy :"
echo "        " `pwd`
echo ""

REFLXS1=Reflector_cell_$NbG"gr+Outrefl1"
REFLXS2=Reflector_cell_$NbG"gr+Outrefl2"
REFLXS3=Reflector_cell_$NbG"gr+Outrefl3"
REFLXS5=Reflector_cell_$NbG"gr+Outrefl5"
REFLXS6=Reflector_cell_$NbG"gr+Outrefl6"
REFLXS7=Reflector_cell_$NbG"gr+Outrefl7"

cp -v $REFLXS1 $DIRXS/XSOUT1.edi
cp -v $REFLXS2 $DIRXS/XSOUT2.edi
cp -v $REFLXS3 $DIRXS/XSOUT3.edi
cp -v $REFLXS5 $DIRXS/XSOUT12.edi
cp -v $REFLXS6 $DIRXS/XSOUT13.edi
cp -v $REFLXS7 $DIRXS/XSOUT14.edi

echo "   "
echo "List cross-sections in /xs to check dates"
cd $DIRXS
ls -l *.edi | cut -c 33-
echo ""
ls -l *.N | cut -c 33-
echo "  "
echo "Recall : you ordered XS for a P1 calculation in INSTANT"
echo "End of transfer, check if XS were well transfered"


